@@ -22,4 +22,10 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 TextureSDL::~TextureSDL()
 {
     SDL_FreeSurface(surface);
+
+    if(zoomSurface)
+    {
+        SDL_FreeSurface(zoomSurface);
+        zoomSurface = NULL;
+    }
 }
