@@ -42,6 +42,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "Util.hpp"
 #include "HelpWindow.hpp"
 
+extern void ok_dial_box(const char *, int, const char *);
+
 ButtonPanel *ButtonPanelInstance=0;
 
 int selected_module_type = CST_NONE;
@@ -173,7 +175,7 @@ bool ButtonPanel::enoughTech( int moduleType ){
 }
 
 /*
- * enable/disabel buttons accordig to tech.
+ * enable/disable buttons according to tech.
  *  lincity/ldsvguts.cpp
  *  oldgui/module_buttons.cpp
  */
@@ -230,7 +232,7 @@ void ButtonPanel::examineButton( std::string name, int showInfo ){
         return;
     }
     doButton( name );
-	if ( enoughTech( selected_module_type ) ){
+    if ( enoughTech( selected_module_type ) ){
         if( !b->isEnabled() ){
             newTechMessage( selected_module_type, showInfo );
             b->setTooltip( createTooltip( selected_module_type, false ) );
@@ -246,6 +248,15 @@ void ButtonPanel::examineButton( std::string name, int showInfo ){
             b->setTooltip(tooltip);
         }
     }
+    if ( (name=="BPMWaterwellButton") & !use_waterwell ) {
+            b->enable( false );
+            char tooltip[2048];
+            snprintf(tooltip, sizeof(tooltip), _("%s is disabled (loaded old game)."),
+	    		createTooltip(selected_module_type, false ).c_str());
+	    b->setTooltip(tooltip);
+    }
+
+
     selected_module_type = tmp;
 }
 
@@ -398,7 +409,15 @@ void ButtonPanel::attachButtons()
         if(b)
         {
           b->clicked.connect(makeCallback(*this, &ButtonPanel::menuButtonClicked));
-          b->setTooltip( createTooltip( mMenuSelected[ mMenus[ i ] ] ) );
+          if( b->isEnabled() ){
+            b->setTooltip( createTooltip( mMenuSelected[ mMenus[ i ] ] ) );
+          } else {  
+            char tooltip[2048];
+            snprintf(tooltip, sizeof(tooltip), _("%s (Techlevel %.1f required.)"), 
+                     createTooltip( mMenuSelected[ mMenus[ i ] ] ).c_str(),
+                     requiredTech( mMenuSelected[ mMenus[ i ] ]));
+            b->setTooltip(tooltip);
+          }
         }
       }
     } 
@@ -413,7 +432,15 @@ void ButtonPanel::attachButtons()
         {
           b->clicked.connect(makeCallback(*this, &ButtonPanel::chooseButtonClicked));
           doButton( mButtons[i] );
-          b->setTooltip( createTooltip( selected_module_type, false ) );
+           if( b->isEnabled() ){
+             b->setTooltip( createTooltip( selected_module_type, false ) );
+	       } else {  
+            char tooltip[2048];
+            snprintf(tooltip, sizeof(tooltip), _("%s (Techlevel %.1f required.)"), 
+                     createTooltip( selected_module_type, false ).c_str(),
+                     requiredTech(selected_module_type));
+            b->setTooltip(tooltip);
+          }
         }
       }
     } 
@@ -562,6 +589,8 @@ void ButtonPanel::showToolHelp( int tooltype ){
             getGame()->showHelpWindow( "park" ); break;
         case CST_WATER:
             getGame()->showHelpWindow( "river" ); break;
+        case CST_WATERWELL:
+            getGame()->showHelpWindow( "waterwell" ); break;
         default:
             std::cerr << "ButtonPanel::showToolHelp# unknown Type " << tooltype << "\n";
     }
@@ -617,6 +646,7 @@ void ButtonPanel::switchToTool( int newModuleType ){
         case CST_MONUMENT_0: newName ="BPMMonumentButton"; break;
         case CST_PARKLAND_PLANE: newName ="BPMParkButton"; break;
         case CST_WATER: newName ="BPMWaterButton"; break;
+        case CST_WATERWELL: newName ="BPMWaterwellButton"; break;
         default:
             std::cerr << "ButtonPanel::switchToTool# unknown Type " << newModuleType << "\n";
             newName ="BPMPointerButton";
@@ -893,6 +923,8 @@ void ButtonPanel::doButton(const std::string &button)
         selected_module_type=CST_PARKLAND_PLANE;
     else if(button=="BPMWaterButton")
         selected_module_type=CST_WATER;
+    else if(button=="BPMWaterwellButton")
+        selected_module_type=CST_WATERWELL;
 }
 
 void ButtonPanel::updateSelectedCost()
