@@ -20,6 +20,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "Config.hpp"
 #include "gui/XmlReader.hpp"
 #include "PhysfsStream/PhysfsStream.hpp"
+#include "lincity/engglobs.h"
 
 #include <SDL_opengl.h>
 #include <assert.h>
@@ -54,15 +55,12 @@ Config::Config()
     musicEnabled = true;
     restartOnChangeScreen = true;
      
-    showDay = true;
-    instantBulldoze = true;
-
     //#define MONTHGRAPH_W 120 
     //#define MONTHGRAPH_H 64
     monthgraphW = 190;
     monthgraphH = 64;
     skipMonthsFast = 1;
-    upgradeTransport = true;
+    quickness = FAST_TIME_FOR_YEAR;
 
     playSongName = "02 - Robert van Herk - City Blues.ogg";
     //First we load the global File which should contain
@@ -170,16 +168,12 @@ void Config::load( const std::string& filename ){
                     const char* value = (const char*) iter.getValue();
                     if(strcmp(name, "skipMonthsFast" ) == 0) {
                         skipMonthsFast = parseInt( value, 1, 1 );
-                    } else if( strcmp(name, "upgradeTransport" ) == 0 ){
-                       upgradeTransport  = parseBool(value, true);
-                    } else if( strcmp(name, "instantBulldoze" ) == 0 ){
-                       instantBulldoze = parseBool(value, true);
-                    } else if( strcmp(name, "showDay" ) == 0 ){
-                       showDay = parseBool(value, true);
                     } else if( strcmp(name, "monthgraphW" ) == 0 ){
                        monthgraphW  = parseInt(value, 120, 0);
                     } else if( strcmp(name, "monthgraphH" ) == 0 ){
                        monthgraphH  = parseInt(value, 64, 0);
+                    } else if( strcmp(name, "quickness" ) == 0 ){
+                        quickness = parseInt(value, 9, 1, 9);
                     } else {
                         std::cerr << "Config::load# Unknown attribute '" << name;
                         std::cerr << "' in element '" << element << "' from " << filename << ".\n";
@@ -226,9 +220,7 @@ Config::save(){
     userconfig << "           musicEnabled=\"" << (musicEnabled?"yes":"no")  
         << "\" musicVolume=\"" << musicVolume << "\"\n";
     userconfig << "           playSongName=\"" << playSongName << "\" />\n";
-    userconfig << "    <game upgradeTransport=\""<< (upgradeTransport?"yes":"no");
-    userconfig << "\" instantBulldoze=\""<< (instantBulldoze?"yes":"no");
-    userconfig <<"\" showDay=\""<<( showDay?"yes":"no") <<"\" />\n";
+    userconfig << "    <game quickness=\""<< quickness <<"\" />\n";
     userconfig << "</configuration>\n";
 }
 
