@@ -39,6 +39,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "Dialog.hpp"
 #include "EconomyGraph.hpp"
 
+extern int lincitySpeed;
+
 Game* gameptr = 0;
 
 Game* getGame(){
@@ -106,8 +108,7 @@ void Game::quickLoad(){
     //load file
     getGameView()->printStatusMessage( "quick load...");
     std::string filename;
-    filename.append( lc_save_dir );
-    filename.append( "/quicksave.scn" );
+    filename.append( "quicksave.scn" );
     if( loadCityNG( filename ) ){
           getGameView()->printStatusMessage( "quick load successful.");
     } else {
@@ -236,27 +237,20 @@ Game::run()
         if(desktop->needsRedraw()) {
             desktop->draw(*painter);
             flipScreenBuffer();
-            // Should we give the CPU some time to relax ?
-            // SDL_Delay(10); 
-        } else {
-            // give the CPU time to relax...
-            SDL_Delay(10);
-            // On athlon-xp 2200+ (1600MHz) this is the limiting factor for max_speed
-            // Removing it gives approximately the same speed as old-ng = 4.0 s/year
-            // instead of 24s/year with delay 10.
-            // SDL doc says to rely on at least 10 ms granurality.
-        }
+        } 
         frame++;
 
-        if(ticks - fpsTicks > 1000) {
+        // Slow down cpu consumption in pause mode
+        if(ticks - fpsTicks > 1000 && lincitySpeed) {
 #ifdef DEBUG_FPS
             printf("FPS: %d.\n", (frame*1000) / (ticks - fpsTicks));
 #endif
             getEconomyGraph()->newFPS( frame );
             frame = 0;
             fpsTicks = ticks;
-        }
-
+        } else if(!lincitySpeed)
+            frame = 0;
+        /* SDL_Delay is done in execute_timestep , which is called by doLincityStep */
         doLincityStep();
     }
 
