@@ -53,6 +53,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "gui/Button.hpp"
 #include "CheckButton.hpp"
 
+extern int is_allowed_here(int x, int y, short cst_type, short msg);
+
 const float GameView::defaultTileWidth = 128;
 const float GameView::defaultTileHeight = 64;
 const float GameView::defaultZoom = 0.5;
@@ -130,6 +132,7 @@ void GameView::parse(XmlReader& reader)
     stopThread = false;
     SDL_mutexP( mThreadRunning );
     loaderThread = SDL_CreateThread( gameViewThread, this );
+    SDL_mutexV( mThreadRunning );
    
     //GameView is resizable
     setFlags(FLAG_RESIZABLE);
@@ -481,6 +484,25 @@ void GameView::loadTextures()
            -e 's/"/.png" );/2'                 
    */
    preReadCityTexture( CST_GREEN, 	"green.png" );
+   preReadCityTexture( CST_DESERT_0, 	"desert_0.png" );
+   preReadCityTexture( CST_DESERT_1L, 	"desert_1l.png" );
+   preReadCityTexture( CST_DESERT_1R, 	"desert_1r.png" );
+   preReadCityTexture( CST_DESERT_1U, 	"desert_1u.png" );
+   preReadCityTexture( CST_DESERT_1D, 	"desert_1d.png" );
+   preReadCityTexture( CST_DESERT_2LR, 	"desert_2lr.png" );
+   preReadCityTexture( CST_DESERT_2LU, 	"desert_2lu.png" );
+   preReadCityTexture( CST_DESERT_2LD, 	"desert_2ld.png" );
+   preReadCityTexture( CST_DESERT_2RU, 	"desert_2ru.png" );
+   preReadCityTexture( CST_DESERT_2RD, 	"desert_2rd.png" );
+   preReadCityTexture( CST_DESERT_2UD, 	"desert_2ud.png" );
+   preReadCityTexture( CST_DESERT_3LRD,	"desert_3lrd.png" );
+   preReadCityTexture( CST_DESERT_3LRU,	"desert_3lru.png" );
+   preReadCityTexture( CST_DESERT_3LUD,	"desert_3lud.png" );
+   preReadCityTexture( CST_DESERT_3RUD,	"desert_3rud.png" );
+   preReadCityTexture( CST_DESERT, 	"desert.png" );
+   preReadCityTexture( CST_TREE, 	"tree.png" );
+   preReadCityTexture( CST_TREE2, 	"tree2.png" );
+   preReadCityTexture( CST_TREE3, 	"tree3.png" );
    preReadCityTexture( CST_POWERL_H_L, "powerlhl.png" );
    preReadCityTexture( CST_POWERL_V_L,  	"powerlvl.png" );
    preReadCityTexture( CST_POWERL_LD_L, 	"powerlldl.png" );
@@ -651,6 +673,7 @@ void GameView::loadTextures()
    preReadCityTexture( CST_WATER_LUR,         "waterlur.png" );
    preReadCityTexture( CST_WATER_URD,         "waterurd.png" );
    preReadCityTexture( CST_WATER_LURD,        "waterlurd.png" );
+   preReadCityTexture( CST_WATERWELL,         "waterwell.png" );
    preReadCityTexture( CST_CRICKET_1,         "cricket1.png" );
    preReadCityTexture( CST_CRICKET_2,         "cricket2.png" );
    preReadCityTexture( CST_CRICKET_3,         "cricket3.png" );
@@ -750,9 +773,42 @@ void GameView::loadTextures()
    //preReadCityTexture( CST_FARM_O14,           "farm14.png" );
    preReadCityTexture( CST_FARM_O15,           "farm15.png" );
    //preReadCityTexture( CST_FARM_O16,           "farm16.png" );
+   preReadCityTexture( CST_TRACK_BRIDGE_LR,    "Trackbridge2.png" );
+   preReadCityTexture( CST_TRACK_BRIDGE_UD,    "Trackbridge1.png" );
+   preReadCityTexture( CST_TRACK_BRIDGE_LRP,   "Trackbridge_pg1.png" );
+   preReadCityTexture( CST_TRACK_BRIDGE_UDP,   "Trackbridge_pg2.png" );
+   preReadCityTexture( CST_TRACK_BRIDGE_ILR,   "Trackbridge_entrance_270.png" );
+   preReadCityTexture( CST_TRACK_BRIDGE_OLR,   "Trackbridge_entrance_90.png" );
+   preReadCityTexture( CST_TRACK_BRIDGE_IUD,   "Trackbridge_entrance_00.png" );
+   preReadCityTexture( CST_TRACK_BRIDGE_OUD,   "Trackbridge_entrance_180.png" );
+   preReadCityTexture( CST_ROAD_BRIDGE_LR,     "Roadbridge1.png" );
+   preReadCityTexture( CST_ROAD_BRIDGE_UD,     "Roadbridge2.png" );
+   preReadCityTexture( CST_ROAD_BRIDGE_LRP,    "Roadbridge1s.png" );
+   preReadCityTexture( CST_ROAD_BRIDGE_UDP,    "Roadbridge2s.png" );
+   preReadCityTexture( CST_ROAD_BRIDGE_LRPG,   "Roadbridge_pg1.png" );
+   preReadCityTexture( CST_ROAD_BRIDGE_UDPG,   "Roadbridge_pg2.png" );
+   preReadCityTexture( CST_ROAD_BRIDGE_I1LR,   "Roadbridge_entrance1_270.png" );
+   preReadCityTexture( CST_ROAD_BRIDGE_O1LR,   "Roadbridge_entrance1_90.png" );
+   preReadCityTexture( CST_ROAD_BRIDGE_I1UD,   "Roadbridge_entrance1_00.png" );
+   preReadCityTexture( CST_ROAD_BRIDGE_O1UD,   "Roadbridge_entrance1_180.png" );
+   preReadCityTexture( CST_ROAD_BRIDGE_I2LR,   "Roadbridge_entrance2_270.png" );
+   preReadCityTexture( CST_ROAD_BRIDGE_O2LR,   "Roadbridge_entrance2_90.png" );
+   preReadCityTexture( CST_ROAD_BRIDGE_I2UD,   "Roadbridge_entrance2_00.png" );
+   preReadCityTexture( CST_ROAD_BRIDGE_O2UD,   "Roadbridge_entrance2_180.png" );
+   preReadCityTexture( CST_RAIL_BRIDGE_LR,     "Railbridge1.png" );
+   preReadCityTexture( CST_RAIL_BRIDGE_UD,     "Railbridge2.png" );
+   preReadCityTexture( CST_RAIL_BRIDGE_LRPG,   "Railbridge_pg1.png" );
+   preReadCityTexture( CST_RAIL_BRIDGE_UDPG,   "Railbridge_pg2.png" );
+   preReadCityTexture( CST_RAIL_BRIDGE_I1LR,   "Railbridge_entrance1_270.png" );
+   preReadCityTexture( CST_RAIL_BRIDGE_O1LR,   "Railbridge_entrance1_90.png" );
+   preReadCityTexture( CST_RAIL_BRIDGE_I1UD,   "Railbridge_entrance1_00.png" );
+   preReadCityTexture( CST_RAIL_BRIDGE_O1UD,   "Railbridge_entrance1_180.png" );
+   preReadCityTexture( CST_RAIL_BRIDGE_I2LR,   "Railbridge_entrance2_270.png" );
+   preReadCityTexture( CST_RAIL_BRIDGE_O2LR,   "Railbridge_entrance2_90.png" );
+   preReadCityTexture( CST_RAIL_BRIDGE_I2UD,   "Railbridge_entrance2_00.png" );
+   preReadCityTexture( CST_RAIL_BRIDGE_O2UD,   "Railbridge_entrance2_180.png" );
    
    // End of generated Code.
-   SDL_mutexV( mThreadRunning );
 }
 
 /*
@@ -843,10 +899,12 @@ void GameView::event(const Event& event)
             if( roadDragging && ( cursorSize != 1 ) ){
                 roadDragging = false;
             }
-            if( roadDragging && ( selected_module_type == CST_GREEN ) 
-                    && getConfig()->instantBulldoze ){ 
-                editMap( tile, SDL_BUTTON_LEFT);
-                startRoad = tile;
+            // bulldoze at once while still dragging
+            if( roadDragging && (selected_module_type == CST_GREEN) ){ 
+                if( tile != startRoad ){
+                    editMap( startRoad, SDL_BUTTON_LEFT);
+                    startRoad = tile;
+                }
             }
  
             if(tileUnderMouse != tile) {
@@ -1314,6 +1372,9 @@ void GameView::drawTile(Painter& painter, MapPoint tile)
     
     if( texture && ( !hideHigh || size == 1 ) )
     {
+        /* TODO: it seems possible to put green or desert tile first,
+         * so that buildings without ground will look nice
+         * especially power lines :) */
         tileOnScreenPoint.x -= cityTextureX[textureType] * zoom;
         tileOnScreenPoint.y -= cityTextureY[textureType] * zoom;  
         tilerect.move( tileOnScreenPoint );    
@@ -1355,36 +1416,33 @@ void GameView::markTile( Painter& painter, MapPoint tile )
         Color alphablue( 0, 0, 255, 128 );
         Color alphared( 255, 0, 0, 128 );
         painter.setFillColor( alphablue );
-        //check if building is allowed here, if not use Red Cursor
+        //check if building is inside the map, if not use Red Cursor
         int x = (int) tile.x;
         int y = (int) tile.y;
         MapPoint seCorner( x + cursorSize -1, y + cursorSize -1 );
         if( !inCity( seCorner ) || !inCity( tile ) ) {
             painter.setFillColor( alphared );
         } else {
-            for( y = (int) tile.y; y < tile.y + cursorSize; y++ ) {
-                for( x = (int) tile.x; x < tile.x + cursorSize; x++ ) {
-                    if( MP_TYPE( x, y ) != CST_GREEN ) {
-                        painter.setFillColor( alphared );
-                        y += cursorSize;
-                        break;
+            for( y = (int) tile.y; y < tile.y + cursorSize; y++ ){
+                for( x = (int) tile.x; x < tile.x + cursorSize; x++ ){
+                    if( !GROUP_IS_BARE(MP_GROUP( x, y ))) {
+                        if( !((MP_GROUP( x, y ) == GROUP_WATER) && ( // bridge on water is OK
+                           (selected_module_type == CST_TRACK_LR ) ||
+                           (selected_module_type == CST_ROAD_LR ) || 
+                           (selected_module_type == CST_RAIL_LR ) ))) {
+                            painter.setFillColor( alphared );
+                            y += cursorSize;
+                            break;
+                        }
                     }
                 }
             }
         }
-        //special conditions for some buildings
-        //
-        //The Harbour needs a River on the East side.
-        if( selected_module_type == CST_EX_PORT ){
-            x = (int) tile.x + cursorSize;
-            y = (int) tile.y;
-            for( y = (int) tile.y; y < tile.y + cursorSize; y++ ) {
-                if (!( ( MP_GROUP( x, y ) == GROUP_WATER ) && ( MP_INFO(x,y).flags & FLAG_IS_RIVER ) ) ){
-                    painter.setFillColor( alphared );
-                }
-            }
-        }
-            
+        //check if building is allowed here, if not use Red Cursor
+        // These tests are in engine.cpp with place_item.
+        if ( !is_allowed_here(tile.x, tile.y, selected_module_type, 0) )
+            painter.setFillColor( alphared );
+
         Rect2D tilerect( 0, 0, tileWidth * cursorSize, tileHeight * cursorSize );
         tileOnScreenPoint.x = tileOnScreenPoint.x - (tileWidth * cursorSize / 2);
         tileOnScreenPoint.y -= tileHeight; 
@@ -1431,6 +1489,7 @@ void GameView::markTile( Painter& painter, MapPoint tile )
             //case CST_MONUMENT_0: break;
             //case CST_PARKLAND_PLANE: break;
             //case CST_WATER: break;
+            case CST_WATERWELL: range = WATERWELL_RANGE; break;
         }
        	
         if (range > 0 )
@@ -1474,13 +1533,15 @@ void GameView::draw(Painter& painter)
         outside = true;
     }
     if( outside ){
+        mouseScrollState = 0;   //Avoid clipping in pause mode
+        keyScrollState = 0;
         show( centerTile );
         return;
     }
     //The Corners of The Screen
     //TODO: change here to only draw dirtyRect
     //      dirtyRectangle is the current Clippingarea (if set)
-    //      so we shold get clippingArea (as soon this is implemented) 
+    //      so we should get clippingArea (as soon this is implemented) 
     //      and adjust these Vectors:
     Vector2 upperLeft( 0, 0);
     Vector2 upperRight( getWidth(), 0 );
@@ -1542,18 +1603,23 @@ void GameView::draw(Painter& painter)
             currentTile = startRoad;
             while( currentTile.x != tileUnderMouse.x ) {
                 markTile( painter, currentTile );
-                if( selected_module_type == CST_GREEN && realTile( currentTile ) != lastRazed ){ 
-                    cost += bulldozeCost( currentTile );
-                    lastRazed = realTile( currentTile );
+                //we are speaking of tools, so CST_GREEN == bulldozer
+                if( (selected_module_type == CST_GREEN) && (realTile( currentTile ) != lastRazed) ){ 
+                    	cost += bulldozeCost( currentTile );
+                    	lastRazed = realTile( currentTile );
+                } else {
+                    cost += buildCost( currentTile );
                 }
                 tiles++;
                 currentTile.x += stepx;
             }
             while( currentTile.y != tileUnderMouse.y ) {
                 markTile( painter, currentTile );
-                if( selected_module_type == CST_GREEN && realTile( currentTile ) != lastRazed ){ 
-                    cost += bulldozeCost( currentTile );
-                    lastRazed = realTile( currentTile );
+                if( (selected_module_type == CST_GREEN ) && realTile( currentTile ) != lastRazed ){ 
+                    	cost += bulldozeCost( currentTile );
+                    	lastRazed = realTile( currentTile );
+                } else {
+                    cost += buildCost( currentTile );
                 }
                 tiles++;
                 currentTile.y += stepy;
@@ -1561,11 +1627,13 @@ void GameView::draw(Painter& painter)
         } 
         markTile( painter, tileUnderMouse );
         tiles++;
-        if( selected_module_type == CST_GREEN && realTile( currentTile ) != lastRazed ) { 
-            cost += bulldozeCost( tileUnderMouse );
+        if( (selected_module_type == CST_GREEN ) && realTile( currentTile ) != lastRazed ) { 
+            	  cost += bulldozeCost( tileUnderMouse );
+        } else {
+            cost += buildCost( tileUnderMouse );
         } 
+        std::stringstream prize;
         if( selected_module_type == CST_GREEN ){
-            std::stringstream prize;
             if( roadDragging ){
                 prize << _("Estimated Bulldoze Cost: ");
             } else {
@@ -1577,6 +1645,19 @@ void GameView::draw(Painter& painter)
                 prize << _("n/a");
             }
             printStatusMessage( prize.str() );
+        } else if( selected_module_type == CST_TRACK_LR || selected_module_type == CST_ROAD_LR
+                || selected_module_type == CST_RAIL_LR )
+        {
+            int group = main_types[ selected_module_type ].group;
+            std::string buildingName = main_groups[ group ].name;
+	    prize << dictionaryManager->get_dictionary().translate( buildingName );
+            prize << _(": Cost to build ");
+            if( cost > 0 ) {
+                prize << cost << _("$");
+        } else {
+                prize << _("n/a");
+            }
+            printStatusMessage( prize.str() );
         } else {
            showToolInfo( tiles );
         }    
@@ -1648,14 +1729,45 @@ int GameView::bulldozeCost( MapPoint tile ){
                           MP_INFO(tile.x,tile.y).int_2 );
     else
         group = MP_GROUP( tile.x,tile.y );
-    if (group == 0) {  /* Can't bulldoze grass. */
-        prize = 0; 
-    } else {
-        prize = main_groups[group].bul_cost;
-    }
+    prize = main_groups[group].bul_cost;
     return prize;
 }
 
+int GameView::buildCost( MapPoint tile ){
+    if( selected_module_type == CST_NONE ){
+    	return 0;
+    }    
+    if (MP_TYPE( tile.x, tile.y ) == CST_USED)
+        return 0;
+    if (( selected_module_type == CST_TRACK_LR || selected_module_type == CST_ROAD_LR ||
+        selected_module_type == CST_RAIL_LR) &&
+        // Transport on water need a bridge
+        (MP_GROUP( tile.x, tile.y) == GROUP_WATER ||
+        // upgrade bridge
+        ((selected_module_type == CST_ROAD_LR && (MP_GROUP( tile.x, tile.y) == GROUP_TRACK_BRIDGE)) ||
+        (selected_module_type == CST_RAIL_LR && (MP_GROUP( tile.x, tile.y) == GROUP_TRACK_BRIDGE ||
+        MP_GROUP( tile.x, tile.y) == GROUP_ROAD_BRIDGE))) ) )
+    {
+        switch( selected_module_type ) {
+            case CST_TRACK_LR:
+                return get_group_cost( GROUP_TRACK_BRIDGE );
+            case CST_ROAD_LR:
+                return get_group_cost( GROUP_ROAD_BRIDGE );
+            case CST_RAIL_LR:
+                return get_group_cost( GROUP_RAIL_BRIDGE );
+        }
+    // Not updgrade a transport
+    } else if ( !GROUP_IS_BARE(MP_GROUP( tile.x, tile.y )) && (selected_module_type == CST_TRACK_LR
+            || (selected_module_type == CST_ROAD_LR && (MP_GROUP( tile.x, tile.y) == GROUP_ROAD ||
+                MP_GROUP( tile.x, tile.y) == GROUP_RAIL || MP_GROUP( tile.x, tile.y) == GROUP_RAIL_BRIDGE))
+            || (selected_module_type == CST_RAIL_LR &&
+                (MP_GROUP( tile.x, tile.y) == GROUP_RAIL || MP_GROUP( tile.x, tile.y) == GROUP_RAIL_BRIDGE))
+            || (selected_module_type == CST_WATER && MP_GROUP( tile.x, tile.y) == GROUP_WATER )) ){
+        return 0;
+    }
+   
+    return get_group_cost( main_types[ selected_module_type ].group );
+}
+
 //Register as Component
 IMPLEMENT_COMPONENT_FACTORY(GameView);
-
