@@ -50,6 +50,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include "tinygettext/gettext.hpp"
 
+extern void new_city(int *originx, int *originy, int random_village);
+
 MainMenu::MainMenu()
 {
     loadMainMenu();
@@ -99,11 +101,13 @@ MainMenu::loadMainMenu()
 
 void MainMenu::fillNewGameMenu()
 {
-  char *buttonNames[]={"File0","File1","File2","File3","File4","File5"};
+  const std::string buttonNames[]={"File0","File1","File2","File3","File4","File5"};
   
   char **files= PHYSFS_enumerateFiles("opening");
   
   char **fptr=files;
+
+  fileMap.clear(); 
  
   for(int i=0;i<6;i++)
   {
@@ -119,33 +123,39 @@ void MainMenu::fillNewGameMenu()
     if(*fptr)
     {
       std::string f=*fptr;
-      if(f.length()>5)
+      if(f.length()>5){
         f=f.substr(0,f.length()-4); // truncate .scn
-      button->setCaptionText(f);
+      }
+      // save real name
+      fileMap.insert(std::pair<std::string, std::string>(buttonNames[i], f ));
+      // use translated name for caption 
+      button->setCaptionText(_(f.c_str()));
       fptr++;
     }
     else
       button->setCaptionText("");
   }
   PHYSFS_freeList(files);
+  return;
+  /* Is there a better way to add filenames to the directory? */
+  _("good_times");
+  _("bad_times");
+  _("Beach");
+  _("extreme_arid");
+  _("extreme_wetland");
 }
 
 void MainMenu::fillLoadMenu( bool save /*= false*/ )
 {
-    char *buttonNames[]={"File0","File1","File2","File3","File4","File5"};
+    const std::string buttonNames[]={"File0","File1","File2","File3","File4","File5"};
   
-    //read savegames from lc_save_dir so we can use the original save_city()
-    DIR* lincityDir = opendir( lc_save_dir );
-    if(!lincityDir) {
-        std::cerr << "Warning directory " << lc_save_dir << " doesn't exist.\n";
-        return;
-    }
+    char** rc = PHYSFS_enumerateFiles("/");
 
-    dirent* curfile;
+    char* curfile;
     CheckButton *button;
 
     for(int i=0;i<6;i++) {
-    	dirent* recentfile;
+    	char* recentfile = NULL;
         PHYSFS_sint64 t = 0;
 
         std::stringstream filestart;
@@ -162,41 +172,38 @@ void MainMenu::fillLoadMenu( bool save /*= false*/ )
         else {
             button->clicked.connect(makeCallback(*this,&MainMenu::selectLoadGameButtonClicked));
         }
-        while( ( curfile = readdir( lincityDir ) ) ) { 
-            if(std::string( curfile->d_name ).find( filestart.str() ) == 0 ) {
+        for(char** i = rc; *i != 0; i++){
+            curfile = *i;
+            if(std::string( curfile ).find( filestart.str() ) == 0 ) {
                 // && !( curfile->d_type & DT_DIR  ) ) is not portable. So
                 // don't create a directoy named 2_ in a savegame-directory or
                 // you can no longer load from slot 2.
-	        if (t == 0) {
+    	        if (t == 0) {
                     recentfile = curfile;
-                    t = PHYSFS_getLastModTime(recentfile->d_name);
-                } else {
-                    if (PHYSFS_getLastModTime(curfile->d_name) > t) {
+                    t = PHYSFS_getLastModTime(recentfile);
+              } else {
+                    if (PHYSFS_getLastModTime(curfile) > t) {
 #ifdef DEBUG
-                       	fprintf(stderr," %s is more recent than previous %s\n",
-                                                curfile->d_name, recentfile->d_name);
+                        fprintf(stderr," %s is more recent than previous %s\n",
+                                          curfile, recentfile);
 #endif
                         recentfile = curfile;
-                        t = PHYSFS_getLastModTime(recentfile->d_name);
+                        t = PHYSFS_getLastModTime(recentfile);
                     }
                 }
             }
         }
 #ifdef DEBUG
-        fprintf(stderr,"Most recent file: %s\n\n",recentfile->d_name);
+        fprintf(stderr,"Most recent file: %s\n\n",recentfile);
 #endif
 
         if(t != 0) {
-            std::string f= recentfile->d_name;
+            std::string f= recentfile;
             button->setCaptionText(f);
         } else {
             button->setCaptionText(_("empty"));
         }
-
-        rewinddir(lincityDir);
     }
-
-    closedir(lincityDir);
 }
 
 void
@@ -342,6 +349,13 @@ void
 MainMenu::selectLoadSaveGameButtonClicked(CheckButton* button , int, bool save )
 {
     std::string fc=button->getCaptionText();
+    if( newGameMenu.get()==currentMenu ) {
+        std::map<std::string, std::string>::iterator iter;
+        iter = fileMap.find( button->getName() );
+        if( iter != fileMap.end() ){
+            fc = iter->second;
+        }
+    }
   
     std::string file="";
     
@@ -354,7 +368,7 @@ MainMenu::selectLoadSaveGameButtonClicked(CheckButton* button , int, bool save )
        after an existing one.
     */
        
-    char *bs[]={"File0","File1","File2","File3","File4","File5",""};
+    const std::string bs[]={"File0","File1","File2","File3","File4","File5",""};
     for(int i=0;std::string(bs[i]).length();i++) {
         CheckButton *b=getCheckButton(*currentMenu,bs[i]);
         if(b->getName()!=button->getName()){
@@ -376,24 +390,23 @@ MainMenu::selectLoadSaveGameButtonClicked(CheckButton* button , int, bool save )
         file=fc;
     }
     
-    if(newGameMenu.get()==currentMenu) {
-        mFilename=PHYSFS_getRealDir( file.c_str() );
-    } else {
+    mFilename="";
+    if(newGameMenu.get()!=currentMenu) {
         slotNr = 1 + atoi( 
                 const_cast<char*>(button->getName().substr(4).c_str()) );
         if( file.length() == 0){
             mFilename = "";
             return;
         }
-        mFilename=lc_save_dir;
     }
     
-    mFilename+="/";
     mFilename+=file;
     Uint32 now = SDL_GetTicks();
+
     //doubleclick on Filename loads File
     if( ( fc == doubleClickButtonName ) &&  ( !save ) &&
             ( now - lastClickTick < doubleClickTime ) ) {
+
         lastClickTick = 0;
         doubleClickButtonName = "";
         if( newGameMenu.get() == currentMenu ) {
@@ -570,10 +583,6 @@ MainMenu::newGameButtonClicked(Button* )
 void
 MainMenu::loadGameButtonClicked(Button* )
 {
-    /* FIXME: NG 1.1 initialisation/clear is not enough yet
-     * This should be done in the engine.cpp or simulate.cpp not here:
-     * see clear_game
-     */
     getSound()->playSound( "Click" );
     loadLoadGameMenu();
     switchMenu(loadGameMenu.get());
@@ -598,10 +607,6 @@ MainMenu::creditsBackButtonClicked(Button* )
 void
 MainMenu::newGameStartButtonClicked(Button* )
 {
-    /* FIXME: NG 1.1 initialisation/clear is not enough yet
-     * This should be done in the engine.cpp or simulate.cpp not here:
-     * see clear_game
-     */
     getSound()->playSound( "Click" );
     if( loadCityNG( mFilename ) ){
     	strcpy (given_scene, baseName.c_str());
@@ -615,11 +620,6 @@ void
 MainMenu::newGameStartBareButtonClicked(Button* )
 {
     getSound()->playSound( "Click" );
-    /* FIXME: NG 1.1 initialisation/clear is not enough yet
-     * This should be done in the engine.cpp or simulate.cpp not here:
-     * see clear_game
-     */
-    resetGameStats();
     new_city( &main_screen_originx, &main_screen_originy, 0 );
     GameView* gv = getGameView();
     if( gv ){ gv->readOrigin(); }
@@ -627,37 +627,10 @@ MainMenu::newGameStartBareButtonClicked(Button* )
     running = false;
 }
 
-//looks like not everything es reseted by new_city()
-void MainMenu::resetGameStats(){
-    /* FIXME: NG 1.1 initialisation/clear is not enough yet
-     * This should be done in the engine.cpp or simulate.cpp not here
-     * see clear_game
-     */
-    given_scene[0] = 0;
-    for( int i = 0; i < monthgraph_size; i++ ){
-        monthgraph_pop[i] = 0;
-        monthgraph_starve[i] = 0;
-        monthgraph_nojobs[i] = 0;
-        monthgraph_ppool[i] = 0;
-    } 
-    highest_tech_level = 0;
-    total_pollution_deaths = 0;
-    pollution_deaths_history = 0;
-    total_starve_deaths = 0;
-    starve_deaths_history = 0;
-    total_unemployed_years = 0;
-    unemployed_history = 0;
-}
-
 void
 MainMenu::newGameStartVillageClicked(Button* )
 {
     getSound()->playSound( "Click" );
-    /* FIXME: NG 1.1 initialisation/clear is not enough yet
-     * This should be done in the engine.cpp or simulate.cpp not here
-     * see clear_game
-     */
-    resetGameStats();
     new_city( &main_screen_originx, &main_screen_originy, 1 );
     GameView* gv = getGameView();
     if( gv ){ gv->readOrigin(); }
@@ -692,10 +665,6 @@ MainMenu::gotoMainMenu()
 void
 MainMenu::loadGameLoadButtonClicked(Button *)
 {
-    /* FIXME: NG 1.1 initialisation/clear is not enough yet
-     * This should be done in the engine.cpp or simulate.cpp not here:
-     * see clear_game
-     */
     getSound()->playSound( "Click" );
     if( loadCityNG( mFilename ) ){
         quitState = INGAME;
@@ -799,8 +768,7 @@ MainMenu::run()
             }
         }
 
-        // give the CPU time to relax... (we are in main menu)
-        SDL_Delay(10);
+        SDL_Delay(10); // give the CPU time to relax... (we are in main menu)
 
         if(currentMenu->needsRedraw()) {
             currentMenu->draw(*painter);
