@@ -19,6 +19,10 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #define __MAINMENU_HPP__
 
 #include "main.hpp"
+#include "gui/Paragraph.hpp"
+#include <memory>
+
+#include <map>
 
 class Component;
 class Desktop;
@@ -71,8 +75,6 @@ private:
     void selectLoadSaveGameButtonClicked(CheckButton*,int, bool save );
     void optionsMenuButtonClicked(CheckButton* button, int );
 
-    void resetGameStats();
-    
     std::auto_ptr<Component> mainMenu;
     std::auto_ptr<Component> newGameMenu;
     std::auto_ptr<Component> loadGameMenu;
@@ -90,6 +92,11 @@ private:
     static const Uint32 doubleClickTime = 1000;
     Uint32 lastClickTick;
     std::string doubleClickButtonName;
+    
+    Paragraph* musicParagraph;
+    void changeTrack( bool next);
+
+    std::map<std::string, std::string> fileMap;
 };
 
 #endif
