@@ -50,6 +50,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "Game.hpp"
 #include "HelpWindow.hpp"
 
+extern int get_power(int x, int y, int power, int block_industry);
+
 /** List of mapview buttons. The "" entries separate mapview buttons that are
  * switched
  */
@@ -476,7 +478,7 @@ MiniMap::speedButtonClicked(CheckButton* button, int)
             setLincitySpeed(MED_TIME_FOR_YEAR);
             break;
         case 3:
-            setLincitySpeed(FAST_TIME_FOR_YEAR);
+            setLincitySpeed(fast_time_for_year);
             break;
         default:
             assert(false);
@@ -623,12 +625,45 @@ Color MiniMap::getColor(int x,int y) const
         xx = MP_INFO(x,y).int_1;
         yy = MP_INFO(x,y).int_2;
     }
+    /* FIXME: since here we should use xx, yy and not x,y */
 
     int flags=MP_INFO(xx,yy).flags;
 
     switch(mMode) {
         case NORMAL:
-            return getColorNormal(x,y);
+#ifdef DEBUG
+#define DEBUG_ALTITUDE
+#ifdef DEBUG_ALTITUDE
+            if (GROUP_IS_BARE(MP_GROUP(xx,yy)) ) {
+                // show ground altitude
+                int alt=ground[xx][yy].altitude;
+                if (alt > alt_min + 9 * alt_step)
+                    return Color(255,255,255);          // white
+                else if ( alt > alt_min + 8 * alt_step ) 
+                    return Color(173,173,173);          // bright grey
+                else if ( alt > alt_min + 7 * alt_step )
+                    return Color(130,130,130);          // grey
+                else if ( alt > alt_min + 6 * alt_step )
+                    return Color(197,170,74);           // bright brown
+                else if ( alt > alt_min + 5 * alt_step )
+                    return Color(106,97,41);            // brown
+                else if ( alt > alt_min + 4 * alt_step )
+                    return Color(0,198,0);              // bright green
+                else if ( alt > alt_min + 3 * alt_step ) 
+                    return Color(16,125,8);             // green
+                else if ( alt > alt_min + 2 * alt_step )
+                    return Color(248,229,30);           // yellow
+                else if ( alt > alt_min + 1 * alt_step )
+                    return Color(8,93,255);             // bright blue
+                else
+                    return Color(0,0,0x9F);             // dark blue
+            }
+            else
+#endif
+#endif  //DEBUG
+            {
+                return getColorNormal(xx,yy);
+            }
         case POLLUTION: {
             short p=MP_POL(x,y);
             float v=p/600.0;
@@ -675,6 +710,7 @@ Color MiniMap::getColor(int x,int y) const
             else
                 return makeGrey(getColorNormal(x,y));
         case UB40: {
+            /* Display residence with un/employed people (red / green) == too many people here */
             if (MP_GROUP_IS_RESIDENCE(xx,yy)) {
                 if (MP_INFO(xx,yy).int_1 < -20)
                     return Color(0xFF,0,0);
@@ -682,9 +718,14 @@ Color MiniMap::getColor(int x,int y) const
                     return Color(0x7F,0,0);
                 else
                     return Color(0,0xFF,0);
-            } else {
-                return makeGrey(getColorNormal(x,y));
+            } 
+
+            /* display buildings with unsatisfied requests for jobs (yellow) == too few people here */
+            if ( (MP_INFO(xx,yy).flags & FLAG_LACK_JOBS) > 0) {
+                    return Color(0xFF,0xFF,0); // yellow
             }
+
+            return makeGrey(getColorNormal(xx,yy));
         }
         case COAL: {
             Color c(0x77,0,0);
@@ -709,29 +750,41 @@ Color MiniMap::getColor(int x,int y) const
                 else
                     return Color(0,0xFF,0);
             } else {
-                return makeGrey(getColorNormal(x,y));
+                    if (use_waterwell) {
+                        if ((flags & FLAG_WATERWELL_COVER) != 0)
+                                return makeBlue(getColorNormal(x,y));
+                    }
+                    return makeGrey(getColorNormal(x,y));
             }
         }
         case POWER: {
             Color mc;
-            if (get_power (xx, yy, 1, 1) != 0) {
-                mc=Color(0,0xFF,0);
-            } else if (get_power (xx, yy, 1, 0) != 0) {
-                mc=Color(0,0x7F,0);
-            } else {
-                mc=Color(0xFF,0xFF,0xFF);
+            /* default color = grey */
+            mc=Color(0x3F,0x3F,0x3F);
+            if (MP_INFO(xx, yy).flags & FLAG_ASKED_FOR_POWER) {
+                if ( (MP_INFO(xx, yy).flags & FLAG_GOT_POWER) != 0) {
+                    /* Windmill powered */
+                    if (get_power (xx, yy, 0, 0) != 0)
+                        mc=Color(0,0x7F,0);
+                    /* Normal powered */
+                    if (get_power (xx, yy, 0, 1) != 0)
+                        mc=Color(0,0xFF,0);
+                } else {
+                    /* did not get power */
+                    /* !!! don't call get power here or the flags will be set :-) */
+                        mc=Color(0xFF,0,0); // (red)
+                }
             }
             if (MP_GROUP(xx,yy) == GROUP_POWER_LINE)
                 mc=Color(0xFF,0xFF,0); //yellow
 
-            mc=light(mc,brightness(getColorNormal(x,y)));
             return mc;
         }
         case TRAFFIC: {
             if ( MP_INFO(x,y).flags & FLAG_IS_TRANSPORT ) {
                 float max;
                 float nextValue;
-                if( MP_GROUP(x,y) == GROUP_ROAD){
+                if( MP_GROUP(x,y) == GROUP_ROAD || MP_GROUP(x,y) == GROUP_ROAD_BRIDGE ){
                     max = MP_INFO(x,y).int_1 * 100.0 / MAX_FOOD_ON_ROAD;
                     nextValue = MP_INFO(x,y).int_2 * 100.0 / MAX_JOBS_ON_ROAD;
                     if( nextValue > max ){ max = nextValue; }
@@ -745,7 +798,7 @@ Color MiniMap::getColor(int x,int y) const
                     if( nextValue > max ){ max = nextValue; }
                     nextValue = MP_INFO(x,y).int_7 * 100.0 / MAX_WASTE_ON_ROAD;
                     if( nextValue > max ){ max = nextValue; }
-                } else if( MP_GROUP(x,y) == GROUP_TRACK ) {
+                } else if( MP_GROUP(x,y) == GROUP_TRACK || MP_GROUP(x,y) == GROUP_TRACK_BRIDGE ){
                     max = MP_INFO(x,y).int_1 * 100.0 / MAX_FOOD_ON_TRACK;
                     nextValue = MP_INFO(x,y).int_2 * 100.0 / MAX_JOBS_ON_TRACK;
                     if( nextValue > max ){ max = nextValue; }
