@@ -24,7 +24,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include <stdlib.h>
 #include "lincity/lin-city.h"
 #include "lincity/lctypes.h"
-#include "lincity/lintypes.h"
+#include "lincity/engglobs.h"
 
 static void LG(short type, short group, const char* id)
 {
@@ -94,6 +94,19 @@ load_png_graphics (char* , char* )
     LG(CST_RAIL_UDR,GROUP_RAIL,LCT_RAIL_UDR_G);
     LG(CST_RAIL_LUDR,GROUP_RAIL,LCT_RAIL_LUDR_G);
 
+    LG(CST_RAIL_BRIDGE_LR,GROUP_RAIL_BRIDGE,LCT_RAIL_BRIDGE_LR_G);
+    LG(CST_RAIL_BRIDGE_UD,GROUP_RAIL_BRIDGE,LCT_RAIL_BRIDGE_UD_G);
+    LG(CST_RAIL_BRIDGE_LRPG,GROUP_RAIL_BRIDGE,LCT_RAIL_BRIDGE_LRPG_G);
+    LG(CST_RAIL_BRIDGE_UDPG,GROUP_RAIL_BRIDGE,LCT_RAIL_BRIDGE_UDPG_G);
+    LG(CST_RAIL_BRIDGE_I1LR,GROUP_RAIL,LCT_RAIL_BRIDGE_I1LR_G);
+    LG(CST_RAIL_BRIDGE_O1LR,GROUP_RAIL,LCT_RAIL_BRIDGE_O1LR_G);
+    LG(CST_RAIL_BRIDGE_I1UD,GROUP_RAIL,LCT_RAIL_BRIDGE_I1UD_G);
+    LG(CST_RAIL_BRIDGE_O1UD,GROUP_RAIL,LCT_RAIL_BRIDGE_O1UD_G);
+    LG(CST_RAIL_BRIDGE_I2LR,GROUP_RAIL,LCT_RAIL_BRIDGE_I2LR_G);
+    LG(CST_RAIL_BRIDGE_O2LR,GROUP_RAIL,LCT_RAIL_BRIDGE_O2LR_G);
+    LG(CST_RAIL_BRIDGE_I2UD,GROUP_RAIL,LCT_RAIL_BRIDGE_I2UD_G);
+    LG(CST_RAIL_BRIDGE_O2UD,GROUP_RAIL,LCT_RAIL_BRIDGE_O2UD_G);
+
     LG(CST_ROAD_LR,GROUP_ROAD,LCT_ROAD_LR_G);
     LG(CST_ROAD_LU,GROUP_ROAD,LCT_ROAD_LU_G);
     LG(CST_ROAD_LD,GROUP_ROAD,LCT_ROAD_LD_G);
@@ -106,6 +119,21 @@ load_png_graphics (char* , char* )
     LG(CST_ROAD_UDR,GROUP_ROAD,LCT_ROAD_UDR_G);
     LG(CST_ROAD_LUDR,GROUP_ROAD,LCT_ROAD_LUDR_G);
 
+    LG(CST_ROAD_BRIDGE_LR,GROUP_ROAD_BRIDGE,LCT_ROAD_BRIDGE_LR_G);
+    LG(CST_ROAD_BRIDGE_UD,GROUP_ROAD_BRIDGE,LCT_ROAD_BRIDGE_UD_G);
+    LG(CST_ROAD_BRIDGE_LRP,GROUP_ROAD_BRIDGE,LCT_ROAD_BRIDGE_LRP_G);
+    LG(CST_ROAD_BRIDGE_UDP,GROUP_ROAD_BRIDGE,LCT_ROAD_BRIDGE_UDP_G);
+    LG(CST_ROAD_BRIDGE_LRPG,GROUP_ROAD_BRIDGE,LCT_ROAD_BRIDGE_LRPG_G);
+    LG(CST_ROAD_BRIDGE_UDPG,GROUP_ROAD_BRIDGE,LCT_ROAD_BRIDGE_UDPG_G);
+    LG(CST_ROAD_BRIDGE_I1LR,GROUP_ROAD,LCT_ROAD_BRIDGE_I1LR_G);
+    LG(CST_ROAD_BRIDGE_O1LR,GROUP_ROAD,LCT_ROAD_BRIDGE_O1LR_G);
+    LG(CST_ROAD_BRIDGE_I1UD,GROUP_ROAD,LCT_ROAD_BRIDGE_I1UD_G);
+    LG(CST_ROAD_BRIDGE_O1UD,GROUP_ROAD,LCT_ROAD_BRIDGE_O1UD_G);
+    LG(CST_ROAD_BRIDGE_I2LR,GROUP_ROAD,LCT_ROAD_BRIDGE_I2LR_G);
+    LG(CST_ROAD_BRIDGE_O2LR,GROUP_ROAD,LCT_ROAD_BRIDGE_O2LR_G);
+    LG(CST_ROAD_BRIDGE_I2UD,GROUP_ROAD,LCT_ROAD_BRIDGE_I2UD_G);
+    LG(CST_ROAD_BRIDGE_O2UD,GROUP_ROAD,LCT_ROAD_BRIDGE_O2UD_G);
+
     LG(CST_TRACK_LR,GROUP_TRACK,LCT_TRACK_LR_G);
     LG(CST_TRACK_LU,GROUP_TRACK,LCT_TRACK_LU_G);
     LG(CST_TRACK_LD,GROUP_TRACK,LCT_TRACK_LD_G);
@@ -118,6 +146,15 @@ load_png_graphics (char* , char* )
     LG(CST_TRACK_UDR,GROUP_TRACK,LCT_TRACK_UDR_G);
     LG(CST_TRACK_LUDR,GROUP_TRACK,LCT_TRACK_LUDR_G);
 
+    LG(CST_TRACK_BRIDGE_LR,GROUP_TRACK_BRIDGE,LCT_TRACK_BRIDGE_LR_G);
+    LG(CST_TRACK_BRIDGE_UD,GROUP_TRACK_BRIDGE,LCT_TRACK_BRIDGE_UD_G);
+    LG(CST_TRACK_BRIDGE_LRP,GROUP_TRACK_BRIDGE,LCT_TRACK_BRIDGE_LRP_G);
+    LG(CST_TRACK_BRIDGE_UDP,GROUP_TRACK_BRIDGE,LCT_TRACK_BRIDGE_UDP_G);
+    LG(CST_TRACK_BRIDGE_ILR,GROUP_TRACK,LCT_TRACK_BRIDGE_ILR_G);
+    LG(CST_TRACK_BRIDGE_OLR,GROUP_TRACK,LCT_TRACK_BRIDGE_OLR_G);
+    LG(CST_TRACK_BRIDGE_IUD,GROUP_TRACK,LCT_TRACK_BRIDGE_IUD_G);
+    LG(CST_TRACK_BRIDGE_OUD,GROUP_TRACK,LCT_TRACK_BRIDGE_OUD_G);
+
     LG(CST_WATER,GROUP_WATER,LCT_WATER_G);
     LG(CST_WATER_D,GROUP_WATER,LCT_WATER_D_G);
     LG(CST_WATER_R,GROUP_WATER,LCT_WATER_R_G);
@@ -135,6 +172,8 @@ load_png_graphics (char* , char* )
     LG(CST_WATER_URD,GROUP_WATER,LCT_WATER_URD_G);
     LG(CST_WATER_LURD,GROUP_WATER,LCT_WATER_LURD_G);
 
+    LG(CST_WATERWELL,GROUP_WATERWELL,LCT_WATERWELL_G);
+
     LG(CST_BLACKSMITH_0,GROUP_BLACKSMITH,LCT_BLACKSMITH_0_G);
     LG(CST_BLACKSMITH_1,GROUP_BLACKSMITH,LCT_BLACKSMITH_1_G);
     LG(CST_BLACKSMITH_2,GROUP_BLACKSMITH,LCT_BLACKSMITH_2_G);
@@ -347,6 +386,27 @@ load_png_graphics (char* , char* )
     LG(CST_TIP_7,GROUP_TIP,LCT_TIP_7_G);
     LG(CST_TIP_8,GROUP_TIP,LCT_TIP_8_G);
 
+    LG(CST_DESERT,GROUP_DESERT,LCT_DESERT_G);
+    LG(CST_DESERT_0,GROUP_DESERT,LCT_DESERT_0_G);
+    LG(CST_DESERT_1D,GROUP_DESERT,LCT_DESERT_1D_G);
+    LG(CST_DESERT_1L,GROUP_DESERT,LCT_DESERT_1L_G);
+    LG(CST_DESERT_1R,GROUP_DESERT,LCT_DESERT_1R_G);
+    LG(CST_DESERT_1U,GROUP_DESERT,LCT_DESERT_1U_G);
+    LG(CST_DESERT_2LD,GROUP_DESERT,LCT_DESERT_2LD_G);
+    LG(CST_DESERT_2LR,GROUP_DESERT,LCT_DESERT_2LR_G);
+    LG(CST_DESERT_2LU,GROUP_DESERT,LCT_DESERT_2LU_G);
+    LG(CST_DESERT_2RD,GROUP_DESERT,LCT_DESERT_2RD_G);
+    LG(CST_DESERT_2RU,GROUP_DESERT,LCT_DESERT_2RU_G);
+    LG(CST_DESERT_2UD,GROUP_DESERT,LCT_DESERT_2UD_G);
+    LG(CST_DESERT_3LRD,GROUP_DESERT,LCT_DESERT_3LRD_G);
+    LG(CST_DESERT_3LRU,GROUP_DESERT,LCT_DESERT_3LRU_G);
+    LG(CST_DESERT_3LUD,GROUP_DESERT,LCT_DESERT_3LUD_G);
+    LG(CST_DESERT_3RUD,GROUP_DESERT,LCT_DESERT_3RUD_G);
+
+    LG(CST_TREE,GROUP_TREE,LCT_TREE_G);
+    LG(CST_TREE2,GROUP_TREE2,LCT_TREE2_G);
+    LG(CST_TREE3,GROUP_TREE3,LCT_TREE3_G);
+
     return 0;
 }
 
