@@ -44,6 +44,9 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "Sound.hpp"
 #include "Config.hpp"
 #include "PBar.hpp"
+#include "lincity/loadsave.h"
+#include "lincity/engglobs.h"
+#include "lincity/lin-city.h"
 
 #ifdef ENABLE_BINRELOC
 #include "binreloc.h"
@@ -81,17 +84,18 @@ void initPhysfs(const char* argv0)
 
     // Initialize physfs (this is a slightly modified version of
     // PHYSFS_setSaneConfig
-    const char* application = /* PACKAGE_NAME */ "lincity";
+    const char* application = LC_SAVE_DIR;
     const char* userdir = PHYSFS_getUserDir();
     const char* dirsep = PHYSFS_getDirSeparator();
     char* writedir = new char[strlen(userdir) + strlen(application) + 2];
 
     // Set configuration directory
-    sprintf(writedir, "%s.%s", userdir, application);
+    //sprintf(writedir, "%s.%s", userdir, application);
+    sprintf(writedir, "%s%s", userdir, application);
     if(!PHYSFS_setWriteDir(writedir)) {
         // try to create the directory
         char* mkdir = new char[strlen(application) + 2];
-        sprintf(mkdir, ".%s", application);
+        sprintf(mkdir, "%s", application);
         if(!PHYSFS_setWriteDir(userdir) || !PHYSFS_mkdir(mkdir)) {
             std::ostringstream msg;
             msg << "Failed creating configuration directory '" <<
@@ -111,13 +115,20 @@ void initPhysfs(const char* argv0)
         }
     }
     PHYSFS_addToSearchPath(writedir, 0);
+
+    // add ~/.lincity for old savegames
+    sprintf(writedir, "%s.lincity", userdir);
+    PHYSFS_addToSearchPath(writedir, 1);
     delete[] writedir;
-   
+
+  //TODO: add zips later
     // Search for archives and add them to the search path
     const char* archiveExt = "zip";
     char** rc = PHYSFS_enumerateFiles("/");
     size_t extlen = strlen(archiveExt);
-
+//TODO sort .zip files! so we are sure which patch is first.
+//and change all file access to physfs. what does PHYSFS_getRealDir 
+//do when file in in archive?
     for(char** i = rc; *i != 0; ++i) {
         size_t l = strlen(*i);
         if((l > extlen) && ((*i)[l - extlen - 1] == '.')) {
@@ -178,18 +189,11 @@ void initPhysfs(const char* argv0)
     PHYSFS_permitSymbolicLinks(1);
 
     //show search Path 
-    for(char** i = PHYSFS_getSearchPath(); *i != NULL; i++)
+    for(char** i = PHYSFS_getSearchPath(); *i != NULL; i++){
         printf("[%s] is in the search path.\n", *i);
-
-    // ugly: set LINCITY_HOME environment variable
-    const char* lincityhome = PHYSFS_getRealDir("colour.pal");
-    if(lincityhome == 0) {
-        throw std::runtime_error("Couldn't locate lincity data (colour.pal).");
     }
-    std::cout << "LINCITY_HOME: " << lincityhome << "\n";
-    char tmp[256];
-    snprintf(tmp, sizeof(tmp), "LINCITY_HOME=%s", lincityhome);
-    putenv(tmp);
+    //show write directory
+    printf("[%s] is the write directory.\n", PHYSFS_getWriteDir());
 }
 
 void initVideo(int width, int height)
@@ -374,14 +378,20 @@ void parseCommandLine(int argc, char** argv)
             std::cout << PACKAGE_NAME << " version " << PACKAGE_VERSION << "\n";
             std::cout << "Command line overrides configfiles.\n";
             std::cout << "Known arguments are:\n";
-            std::cout << "-v        --version         show version and exit\n";
-            std::cout << "-h        --help            show his text and exit\n";
-            std::cout << "-g        --gl              use OpenGL\n";
-            std::cout << "-s        --sdl             use SDL\n";
-            std::cout << "-S [size] --size [size]     specify screensize (eg. 1024x768)\n";
-            std::cout << "-w        --window          run in window\n";
-            std::cout << "-f        --fullscreen      run fullscreen\n";
-            std::cout << "-m        --mute            mute audio\n";
+            std::cout << "-v           --version         show version and exit\n";
+            std::cout << "-h           --help            show this text and exit\n";
+            std::cout << "-g           --gl              use OpenGL\n";
+            std::cout << "-s           --sdl             use SDL\n";
+            std::cout << "-S [size]    --size [size]     specify screensize (eg. -S 1024x768)\n";
+            std::cout << "-w           --window          run in window\n";
+            std::cout << "-f           --fullscreen      run fullscreen\n";
+            std::cout << "-m           --mute            mute audio\n";
+            std::cout << "-q [delay]   --quick [delay]   Setting for fast speed (current " \
+                                                                << getConfig()->quickness \
+                                                                << ")\n";
+            std::cout << "                               -q 9 skips animation steps for speed.\n";
+            std::cout << "                               -q 8 is the slowest speed with full animation.\n";
+            std::cout << "                               -q 1 is fastest. It may heat your hardware!\n";
             exit(0);
         } else if(argStr == "-g" || argStr == "--gl") {
             getConfig()->useOpenGL = true;
@@ -414,6 +424,23 @@ void parseCommandLine(int argc, char** argv)
         } else if(argStr == "-m" || argStr == "--mute") {
             getConfig()->soundEnabled = false;
             getConfig()->musicEnabled = false;
+        } else if (argStr == "-q" || argStr == "--quick") {
+            currentArgument++;
+            if(currentArgument >= argc) {
+                std::cerr << "Error: --quick needs a parameter.\n";
+                exit(1);
+            }
+            //fast_time_for_year
+            argStr = argv[currentArgument];
+            int newSpeed;
+            sscanf( argStr.c_str(), "%i", &newSpeed );
+            if ( newSpeed < 1 || newSpeed > 9 ) {
+                fprintf(stderr, " --quick = %i out of range (1..9). Will use default value %i\n", \
+                                newSpeed, FAST_TIME_FOR_YEAR);
+                newSpeed = FAST_TIME_FOR_YEAR;
+            }
+            getConfig()->quickness = newSpeed;
+
         } else {
             std::cerr << "Unknown command line argument: " << argStr << "\n";
             exit(1);
@@ -435,9 +462,7 @@ int main(int argc, char** argv)
         dictionaryManager = new TinyGetText::DictionaryManager();
         dictionaryManager->set_charset("UTF-8");
         dictionaryManager->add_directory("locale");
-#ifdef DEBUG
         std::cout << "Language is \"" << dictionaryManager->get_language() << "\".\n";
-#endif
         
 #ifndef DEBUG
     } catch(std::exception& e) {
@@ -448,14 +473,16 @@ int main(int argc, char** argv)
         return 1;
     }                                                                     
 #endif
-
-    parseCommandLine(argc, argv);
+    parseCommandLine(argc, argv); // Do not use getConfig() before parseCommandLine.
+    
+    fast_time_for_year = getConfig()->quickness;
+    fprintf(stderr," fast = %i\n", fast_time_for_year);
    
 // in debug mode we want a backtrace of the exceptions so we don't catch them
 #ifndef DEBUG
     try {
 #endif
-        xmlInitParser();
+        xmlInitParser ();
         std::auto_ptr<Sound> sound; 
         sound.reset(new Sound()); 
         initSDL();
