@@ -12,9 +12,9 @@
 #endif
 
 #ifndef _MSC_VER
-#warning deprecated header
+//#warning deprecated header
 #else
 #pragma message(__FILE__ ": deprecated header")
 #endif
 
-#endif	/* __lcstring_h__ */
+#endif /* __lcstring_h__ */
