@@ -9,20 +9,8 @@
 
 #include <stdio.h>
 
-#undef commentout
 #define LC_X11
 
-/*
-  The mouse sensitivity can be an integer such as 1, 2, 3 etc.
-  The higher the number the less you have to move the mouse.
-  It's a bit crude, it just multiples the mouse movement by this
-  amount. IMHO 3 is about the maximum useful value, 2 is quite
-  comfortable.
-    ** This is only relevant for linux-svgalib. **
-XXX: Then it shouldn't be here
-*/
-#define MOUSE_SENSITIVITY 1
-
 /*
   When your money reaches 1 million or more, to make it easier to
   read, it is split into two parts; a millions part, and the rest.
@@ -35,51 +23,21 @@ XXX: Then it shouldn't be here
 */
 #define MONEY_SEPARATOR ','
 
-/*
-   #define MP_SANITY_CHECK
-*/
-
-/* The number of milliseconds between scrolling text on the initial screen */
-#define SPLASH_SCROLL_DELAY 30  /* was 30 */
-
 /*
        ************************************************
         NO USER CONFIGURABLE OPTIONS BEYOND THIS POINT
        ************************************************
 */
-
-/* VERSION_INT is used in the load/save code.  All other code uses 
-   the symbol VERSION in config.h */
-#define VERSION_INT 113
-
-/* Don't load if < MIN_LOAD_VERSION */
-#define MIN_LOAD_VERSION 97
-
-/* Load corrections if version <= MM_MS_C_VER (max markets/substations) */
-#define MM_MS_C_VER 97
-
-/* Load corrections if version <= MG_C_VER (max monthgraph size) */
-#define MG_C_VER 111
-
 #if defined (_MSC_VER)
-#define snprintf _snprintf
+#   define snprintf _snprintf
 #endif
-
-#if defined (WIN32)
-#define PATH_SLASH '\\'
-#define PATH_SLASH_STRING "\\"
-#else
-#define PATH_SLASH '/'
-#define PATH_SLASH_STRING "/"
-#endif
-
 #define USE_X11_PIXMAPS
 
 #ifndef TRUE
-#define TRUE 1
+#   define TRUE 1
 #endif
 #ifndef FALSE
-#define FALSE 0
+#   define FALSE 0
 #endif
 
 /* Used by HandleError () */
@@ -88,42 +46,12 @@ XXX: Then it shouldn't be here
 
 /* comment out the the next three lines for _slightly_ faster X drawing. */
 #if defined LC_X11 || defined WIN32
-#define ALLOW_PIX_DOUBLING
+#   define ALLOW_PIX_DOUBLING
 #endif
 
-/*
-  Gamma correction. The numbers GAMMA_CORRECT_X are between 0.0 and 1.0
-  The following values are enabled with the -w option. This seems quite
-  good for 'washed out' monitors that lack red.
-  You can also set the values from the command line.
-   [x]lincity -R 1.0 -G 0.0 -B 0.4  is the same as [x]lincity -w
- */
-#define GAMMA_CORRECT_RED    ((float) 1.0)
-#define GAMMA_CORRECT_GREEN  ((float) 0.0)
-#define GAMMA_CORRECT_BLUE   ((float) 0.4)
-
-#define PROFILE_COUNTDOWN 10000
-
-/* hof is 70 from 28/12 */
-
-/*
-#define DEBUG_ENGINE 1
-   #define ALLOW_TCORE_DUMP
-   #define DEBUG_ROCKETS
-   #define DEBUGMOUSE
-   #define DEBUG_MOUSE
-   #define DEBUG_MAIN_SCREEN
-   #define DEBUG_GET_POWER
-   if DEBUG_KEYS is defined, pressing certain keys add money, tech points etc.
-   #define DEBUG_KEYS 1
-*/
-/*
-   #define CS_PROFILE
-*/
-
 #if defined (LC_X11) || defined (WIN32)
-#define BORDERX 30
-#define BORDERY 30
+#    define BORDERX 30
+#    define BORDERY 30
 #endif
 
 #define TEXT_FG_COLOUR  (white(24))
@@ -140,10 +68,11 @@ XXX: Then it shouldn't be here
    FLAG_M?_* into an int_? variable.  And add more int_? variables.  That keeps
    it simple and squeezes some life out of 32 bits.  I don't think we need to
    hurry.  I'd rather replace the whole scheme. */
-#define FLAG_LEFT               (1)
-#define FLAG_UP                 (2)
-#define FLAG_RIGHT              (4)
-#define FLAG_DOWN               (8)
+
+#define FLAG_LEFT               (1)             // Used for transports, power lines, rivers, and desert borders.
+#define FLAG_UP                 (2)             // Algorithm relies on the numerical values of 
+#define FLAG_RIGHT              (4)             // the flags. (a check is done at compile time)
+#define FLAG_DOWN               (8)             // 
 #define FLAG_POWERED            (0x10)
 #define FLAG_FED                (0x20)
 #define FLAG_EMPLOYED           (0x40)
@@ -165,9 +94,13 @@ XXX: Then it shouldn't be here
 #define FLAG_CRICKET_COVER      (0x400000)
 #define FLAG_IS_RIVER           (0x800000)
 #define FLAG_HAD_POWER          (0x1000000)
-#define FLAG_MULTI_TRANSPORT    (0x2000000)   /* Is it a multitransport? */
-#define FLAG_MULTI_TRANS_PREV   (0x4000000)
+#define FLAG_MULTI_TRANSPORT    (0x2000000)   /* Is it a multitransport? */     /* AL1: unused in NG 1.1 */
+#define FLAG_LACK_JOBS          (0x4000000)     /* 1.92 svn , replace previous unused one. */
 #define FLAG_POWER_LINE         (0x8000000)
+#define FLAG_WATERWELL_COVER    (0x10000000)
+#define FLAG_HAS_UNDERGROUND_WATER (0x20000000)
+#define FLAG_ASKED_FOR_POWER       (0x40000000)
+#define FLAG_GOT_POWER             (0x80000000) /* 2^31 = last flag */  //nearly duplicate of FLAG_POWERED 0x10
 
 /* XXX: It would appear that the following T_ are used exactly two times each,
    in market.c.  */
@@ -179,16 +112,6 @@ XXX: Then it shouldn't be here
 #define T_STEEL 5
 #define T_WASTE 6
 
-/* XXX: Move me to mouse.h or similar */
-
-#define MT_FAIL     0
-#define MT_START    1
-#define MT_CONTINUE 2
-#define MT_SUCCESS  3
-
-#define HOF_START 845830134
-#define HOF_STOP 857843038
-
 /* XXX: screen.h? */
 
 #define MINI_SCREEN_NORMAL_FLAG    (0)
@@ -205,26 +128,12 @@ XXX: Then it shouldn't be here
 #define MAIN_SCREEN_NORMAL_FLAG    (1)
 #define MAIN_SCREEN_EQUALS_MINI    (2)
 
-#define SEED_RAND
-#define OLD_LC_SAVE_DIR "Lin-city"
-#if defined (WIN32)
-#define LC_SAVE_DIR "SAVED_GAMES"
-#define LINCITYRC_FILENAME "lincity.ini"
-#else
-/* GCS: Changed for 1.12 */
-/* #define LC_SAVE_DIR ".Lin-city" */
-#define LC_SAVE_DIR ".lincity"
-#define LINCITYRC_FILENAME ".lincityrc"
-#endif
-#define RESULTS_FILENAME "results"
-
-#define MAX_ICON_LEN 4096
-#define WORLD_SIDE_LEN 100
+#define WORLD_SIDE_LEN 100      /* Minimap size is hardcoded 200 pixel => some job to do ... */
 #define NUMOF_DAYS_IN_MONTH 100
 #define NUMOF_DAYS_IN_YEAR (NUMOF_DAYS_IN_MONTH*12)
-#define FAST_TIME_FOR_YEAR 1
+#define FAST_TIME_FOR_YEAR 9
 #define MED_TIME_FOR_YEAR  20
-#define SLOW_TIME_FOR_YEAR  60
+#define SLOW_TIME_FOR_YEAR 60
 
 /* interest rate *10  ie 10 is 1% */
 #define INTEREST_RATE 15
@@ -242,15 +151,8 @@ XXX: Then it shouldn't be here
 #define BAD (-1)
 #define RESULTS 0
 
-#define PROGBOXX 170
-#define PROGBOXY 180
-#define PROGBOXW 300
-#define PROGBOXH 120
-#define PROGBOX_BG_COLOUR 114
-#define PROGBOX_DONE_COL 4
-#define PROGBOX_NOTDONE_COL 2
+/************* Buildings stuff *********************/
 
-#define POWERS_SOLAR_OUTPUT 1800
 #define WINDMILL_POWER      450
 #define WINDMILL_JOBS       10
 /* WINDMILL_RCOST is days per quid */
@@ -285,7 +187,6 @@ XXX: Then it shouldn't be here
 #define INDUSTRY_L_POL_PER_GOOD 0.05
 #define INDUSTRY_L_POLLUTION    10
 
-
 #define MAX_ORE_AT_INDUSTRY_H 10000
 #define MAX_COAL_AT_INDUSTRY_H 1000
 #define MAX_MADE_AT_INDUSTRY_H MAX_ORE_AT_INDUSTRY_H/16
@@ -302,7 +203,7 @@ XXX: Then it shouldn't be here
 #define ROAD_POLLUTION          1
 #define DAYS_PER_ROAD_POLLUTION 20
 #define UNNAT_DEATHS_COST       500
-#define POL_DIV                 64	/* GCS -- from engine.c */
+#define POL_DIV                 64      /* GCS -- from engine.c */
 
 #define FINANCE_X 91
 #define FINANCE_W 120
@@ -465,19 +366,19 @@ XXX: Then it shouldn't be here
 #define HEALTH_RUNNING_COST_MUL 9
 #define HEALTH_CENTRE_RANGE  15
 
+#define OREMINE_ANIMATION_SPEED 200
+
 #define OLD_MAX_NUMOF_MARKETS 100
 #define MAX_NUMOF_MARKETS 512
 #define MARKET_RANGE      10
 #define MAX_FOOD_ON_TRACK 2048
-#define MAX_FOOD_ON_RIVER (MAX_FOOD_ON_TRACK*2)
 #define MAX_FOOD_ON_ROAD (MAX_FOOD_ON_TRACK*4)
-#define MAX_FOOD_ON_RAIL (MAX_FOOD_ON_ROAD*4)
+#define MAX_FOOD_ON_RAIL (MAX_FOOD_ON_TRACK*16)
 #define MAX_FOOD_IN_MARKET (MAX_FOOD_ON_RAIL*8)
 #define MARKET_FOOD_SEARCH_TRIGGER (MAX_FOOD_IN_MARKET/5)
 #define MAX_JOBS_ON_TRACK 1024
-#define MAX_JOBS_ON_RIVER (MAX_JOBS_ON_TRACK*2)
 #define MAX_JOBS_ON_ROAD (MAX_JOBS_ON_TRACK*5)
-#define MAX_JOBS_ON_RAIL (MAX_JOBS_ON_ROAD*5)
+#define MAX_JOBS_ON_RAIL (MAX_JOBS_ON_TRACK*25)
 #define MAX_JOBS_IN_MARKET (MAX_JOBS_ON_RAIL*3)
 #define MARKET_JOBS_SEARCH_TRIGGER (MAX_JOBS_IN_MARKET/5)
 #define MARKET_ANIM_SPEED 750
@@ -497,15 +398,6 @@ XXX: Then it shouldn't be here
 #define MIN_FOOD_SOLD_FOR_ANIM 200
 #define DAYS_PER_STARVE 20
 
-#define MAX_WASTE_ON_TRACK 1024
-#define MAX_WASTE_ON_ROAD (MAX_WASTE_ON_TRACK*5)
-#define MAX_WASTE_ON_RAIL (MAX_WASTE_ON_ROAD*5)
-#define MAX_WASTE_IN_MARKET (MAX_WASTE_ON_RAIL*3)
-#define MARKET_WASTE_SEARCH_TRIGGER (MAX_WASTE_IN_MARKET/5)
-#define MAX_WASTE_AT_TIP  10000000
-#define WASTE_BURN_ON_TRANSPORT 20
-#define TRANSPORT_BURN_WASTE_COUNT 75000
-
 #define NUMOF_COAL_RESERVES 100
 #define COAL_RESERVE_SIZE 10000
 #define ORE_RESERVE       1000
@@ -525,37 +417,42 @@ XXX: Then it shouldn't be here
 #define COMMUNE_ANIM_SPEED 750
 #define COMMUNE_POP  5
 
-#define DIG_MORE_COAL_TRIGGER (MAX_COAL_AT_MINE)
-#define DIG_MORE_ORE_TRIGGER  (MAX_ORE_AT_MINE)
 #define MAX_COAL_ON_TRACK 64
-#define MAX_COAL_ON_RIVER (MAX_COAL_ON_TRACK*2)
 #define MAX_COAL_ON_ROAD (MAX_COAL_ON_TRACK*8)
-#define MAX_COAL_ON_RAIL (MAX_COAL_ON_ROAD*8)
+#define MAX_COAL_ON_RAIL (MAX_COAL_ON_TRACK*64)
 #define MAX_COAL_IN_MARKET (MAX_COAL_ON_RAIL*2)
 #define MARKET_COAL_SEARCH_TRIGGER (MAX_COAL_IN_MARKET/5)
 
 #define MAX_GOODS_ON_TRACK 2048
-#define MAX_GOODS_ON_RIVER (MAX_GOODS_ON_TRACK*2)
 #define MAX_GOODS_ON_ROAD (MAX_GOODS_ON_TRACK*5)
 #define ROAD_GOODS_USED_MASK 0x1f
-#define MAX_GOODS_ON_RAIL (MAX_GOODS_ON_ROAD*5)
+#define MAX_GOODS_ON_RAIL (MAX_GOODS_ON_TRACK*25)
 #define RAIL_GOODS_USED_MASK 0xf
 #define MAX_GOODS_IN_MARKET (MAX_GOODS_ON_RAIL*4)
 #define MARKET_GOODS_SEARCH_TRIGGER (MAX_GOODS_IN_MARKET/5)
 #define MAX_ORE_ON_TRACK 4096
-#define MAX_ORE_ON_RIVER (MAX_ORE_ON_TRACK*2)
 #define MAX_ORE_ON_ROAD (MAX_ORE_ON_TRACK*4)
-#define MAX_ORE_ON_RAIL (MAX_ORE_ON_ROAD*4)
+#define MAX_ORE_ON_RAIL (MAX_ORE_ON_TRACK*16)
 #define MAX_ORE_IN_MARKET (MAX_ORE_ON_RAIL*2)
 #define MARKET_ORE_SEARCH_TRIGGER (MAX_ORE_IN_MARKET/5)
 
-
 #define MAX_STEEL_ON_TRACK 128
-#define MAX_STEEL_ON_RIVER (MAX_STEEL_ON_TRACK*2)
 #define MAX_STEEL_ON_ROAD (MAX_STEEL_ON_TRACK*4)
-#define MAX_STEEL_ON_RAIL (MAX_STEEL_ON_ROAD*4)
+#define MAX_STEEL_ON_RAIL (MAX_STEEL_ON_TRACK*16)
 #define RAIL_STEEL_USED_MASK 0x7f
 #define MAX_STEEL_AT_INDUSTRY_H (MAX_STEEL_ON_RAIL*10)
+
+#define MAX_WASTE_ON_TRACK 1024
+#define MAX_WASTE_ON_ROAD (MAX_WASTE_ON_TRACK*5)
+#define MAX_WASTE_ON_RAIL (MAX_WASTE_ON_TRACK*25)
+#define MAX_WASTE_IN_MARKET (MAX_WASTE_ON_RAIL*3)
+#define MARKET_WASTE_SEARCH_TRIGGER (MAX_WASTE_IN_MARKET/5)
+#define MAX_WASTE_AT_TIP  10000000
+#define WASTE_BURN_ON_TRANSPORT 20
+#define TRANSPORT_BURN_WASTE_COUNT 75000
+
+#define WATERWELL_RANGE 20
+
 /*
   JOBS_MAKE_STEEL is the steel made per job at the steel works
   what's it doing here?
@@ -590,61 +487,18 @@ XXX: Then it shouldn't be here
 #define STATS_W 304
 #define STATS_H 32
 
-/* GCS FIX: This is still used in static data structure for size 
-   of monthgraph.  Fix by encapsulating the monthgraph and dynamically
-   allocating.  */
-#if defined (commentout)
-#ifndef MONTHGRAPH_W
-#define MONTHGRAPH_X 91
-#define MONTHGRAPH_W 120
-#define MONTHGRAPH_Y 116
-#define MONTHGRAPH_H 64
-#endif
-#define DIFFGRAPH_POWER_COLOUR (yellow(28))
-#define DIFFGRAPH_COAL_COLOUR  (white(18))
-#define DIFFGRAPH_GOODS_COLOUR (cyan(24))
-#define DIFFGRAPH_ORE_COLOUR   (red(22))
-#define DIFFGRAPH_POPULATION_COLOUR 7
-#endif
-
 #define GRAPHS_B_COLOUR (white(6))
 
-/* These constants are still used by save-under buffer */
-#if defined (commentout)
-#define MARKET_CB_X (79)
-#define MARKET_CB_Y 0
-#endif
 //#define MARKET_CB_W (18*8)
 #define MARKET_CB_W (17*8 - 2)
 #define MARKET_CB_H (23*8)
 
-#define SCROLL_LONG_COUNT 5
-#define SCROLL_RIGHT_BUTTON_X 100
-#define SCROLL_RIGHT_BUTTON_W 32
-#define SCROLL_RIGHT_BUTTON_Y 100
-#define SCROLL_RIGHT_BUTTON_H 32
-#define SCROLL_LEFT_BUTTON_X 100
-#define SCROLL_LEFT_BUTTON_W 32
-#define SCROLL_LEFT_BUTTON_Y 132
-#define SCROLL_LEFT_BUTTON_H 32
-#define SCROLL_DOWN_BUTTON_X 100
-#define SCROLL_DOWN_BUTTON_W 32
-#define SCROLL_DOWN_BUTTON_Y 164
-#define SCROLL_DOWN_BUTTON_H 32
-#define SCROLL_UP_BUTTON_X 100
-#define SCROLL_UP_BUTTON_W 32
-#define SCROLL_UP_BUTTON_Y 196
-#define SCROLL_UP_BUTTON_H 32
-
 #define SHUFFLE_MAPPOINT_COUNT 4
 
-#if defined (commentout)
-#define MAPPOINT_STATS_X 91
-/* MAPPOINT_STATS_W must be == MONTHGRAPH_W because of the graph drawing. */
-#define MAPPOINT_STATS_W MONTHGRAPH_W
-#define MAPPOINT_STATS_Y 8
-#define MAPPOINT_STATS_H (11*8)
-#endif
+/******* Buildings // GROUPS ************/ 
+#define NUM_OF_TYPES    404
+#define NUM_OF_GROUPS    50
+#define GROUP_NAME_LEN   20
 
 #define GROUP_BARE 	   0
 #define GROUP_BARE_COLOUR  (green(12))
@@ -668,8 +522,9 @@ XXX: Then it shouldn't be here
 #define GROUP_SOLAR_POWER_COST_MUL 5
 #define GROUP_SOLAR_POWER_BUL_COST 100000
 #define GROUP_SOLAR_POWER_TECH 500
-#define GROUP_SOLAR_POWER_NO_CREDIT
 #define GROUP_SOLAR_POWER_FIREC 33
+#define SOLAR_POWER_JOBS 50
+#define POWERS_SOLAR_OUTPUT 1800
 
 #define GROUP_SUBSTATION   3
 #define GROUP_SUBSTATION_COLOUR (yellow(18))
@@ -687,39 +542,6 @@ XXX: Then it shouldn't be here
 #define GROUP_RESIDENCE_LL_TECH 0
 #define GROUP_RESIDENCE_LL_FIREC 75
 
-#if defined (commentout)
-#define RESIDENCE_BASE_BR     100
-#define RESIDENCE_BRM_HEALTH  5
-#define RESIDENCE_BASE_DR     (68*12)
-#define GROUP_RESIDENCE    4
-#define GROUP_RESIDENCE_COLOUR (cyan(24))
-#define GROUP_RESIDENCE_COST   0
-#define GROUP_RESIDENCE_COST1  1000
-#define RESIDENCE1_BRM (RESIDENCE_BASE_BR*12)
-#define RESIDENCE1_DRM ((RESIDENCE_BASE_DR*3)/4)
-#define GROUP_RESIDENCE_COST2  2000
-#define RESIDENCE2_BRM 0
-#define RESIDENCE2_DRM 0
-#define GROUP_RESIDENCE_COST3  4000
-#define RESIDENCE3_BRM (RESIDENCE_BASE_BR+RESIDENCE_BASE_BR/4)
-#define RESIDENCE3_DRM ((RESIDENCE_BASE_DR)/2)
-#define GROUP_RESIDENCE_COST4  800
-#define RESIDENCE4_BRM (RESIDENCE_BASE_BR*18)
-#define RESIDENCE4_DRM ((RESIDENCE_BASE_DR*3)/4)
-#define GROUP_RESIDENCE_COST5  1600
-#define RESIDENCE5_BRM (RESIDENCE_BASE_BR/2)
-#define RESIDENCE5_DRM ((RESIDENCE_BASE_DR)/4)
-#define GROUP_RESIDENCE_COST6  3200
-#define RESIDENCE6_BRM 0
-#define RESIDENCE6_DRM ((RESIDENCE_BASE_DR)/4)
-#define GROUP_RESIDENCE_COST_MUL 25
-#define GROUP_RESIDENCE_BUL_COST 1000
-#define GROUP_RESIDENCE_TECH 0
-#define GROUP_RESIDENCE_FIREC 75
-/* RESIDENCE_PPM is the people_pool mobitily. Higher number=less mobile. */
-#define RESIDENCE_PPM   20
-#endif
-
 /* RESIDENCE?_BRM is the birth rate modifier */
 /* RESIDENCE?_DRM is the death rate modifier */
 #define RESIDENCE_BASE_BR     100
@@ -757,7 +579,7 @@ XXX: Then it shouldn't be here
 #define GROUP_MARKET_FIREC 80
 
 #define GROUP_TRACK	   7
-#define GROUP_TRACK_COLOUR 32	/* 32 is a brown */
+#define GROUP_TRACK_COLOUR 32   /* 32 is a brown */
 #define GROUP_TRACK_COST   1
 #define GROUP_TRACK_COST_MUL 25
 #define GROUP_TRACK_BUL_COST   10
@@ -810,7 +632,6 @@ XXX: Then it shouldn't be here
 #define GROUP_UNIVERSITY_COST_MUL 25
 #define GROUP_UNIVERSITY_BUL_COST 20000
 #define GROUP_UNIVERSITY_TECH 150
-#define GROUP_UNIVERSITY_NO_CREDIT
 #define GROUP_UNIVERSITY_FIREC 40
 
 #define GROUP_COMMUNE      14
@@ -846,7 +667,7 @@ XXX: Then it shouldn't be here
 #define GROUP_PORT_FIREC 50
 
 #define GROUP_INDUSTRY_H   18
-#define GROUP_INDUSTRY_H_COLOUR (7)	/* colour 7 is an orange, sort of */
+#define GROUP_INDUSTRY_H_COLOUR (7)     /* colour 7 is an orange, sort of */
 #define GROUP_INDUSTRY_H_COST 50000
 #define GROUP_INDUSTRY_H_COST_MUL 20
 #define GROUP_INDUSTRY_H_BUL_COST 70000
@@ -859,7 +680,6 @@ XXX: Then it shouldn't be here
 #define GROUP_PARKLAND_COST_MUL 25
 #define GROUP_PARKLAND_BUL_COST   1000
 #define GROUP_PARKLAND_TECH   2
-#define GROUP_PARKLAND_NO_CREDIT
 #define GROUP_PARKLAND_FIREC 1
 
 #define GROUP_RECYCLE      20
@@ -868,7 +688,6 @@ XXX: Then it shouldn't be here
 #define GROUP_RECYCLE_COST_MUL 5
 #define GROUP_RECYCLE_BUL_COST    1000
 #define GROUP_RECYCLE_TECH    232
-#define GROUP_RECYCLE_NO_CREDIT
 #define GROUP_RECYCLE_FIREC 10
 
 #define GROUP_WATER	   21
@@ -877,7 +696,7 @@ XXX: Then it shouldn't be here
 #define GROUP_WATER_COST_MUL 2
 #define GROUP_WATER_BUL_COST      1000000
 #define GROUP_WATER_TECH      0
-#define GROUP_RIVER (GROUP_WATER)	/* oops -- GCS: Why oops? */
+#define GROUP_RIVER (GROUP_WATER)       /* oops -- GCS: Why oops? */
 #define GROUP_WATER_FIREC 0
 
 #define GROUP_HEALTH       22
@@ -894,7 +713,6 @@ XXX: Then it shouldn't be here
 #define GROUP_ROCKET_COST_MUL 2
 #define GROUP_ROCKET_BUL_COST     1
 #define GROUP_ROCKET_TECH     750
-#define GROUP_ROCKET_NO_CREDIT
 #define GROUP_ROCKET_FIREC 0
 
 #define GROUP_WINDMILL     24
@@ -963,18 +781,18 @@ XXX: Then it shouldn't be here
 
 #define GROUP_BURNT        32
 #define GROUP_BURNT_COLOUR    (red(30))
-#define GROUP_BURNT_COST   0        /* Unused */
-#define GROUP_BURNT_COST_MUL   1    /* Unused */
+#define GROUP_BURNT_COST   0    /* Unused */
+#define GROUP_BURNT_COST_MUL   1        /* Unused */
 #define GROUP_BURNT_BUL_COST  1000
-#define GROUP_BURNT_TECH   0        /* Unused */
+#define GROUP_BURNT_TECH   0    /* Unused */
 #define GROUP_BURNT_FIREC  0
 
 #define GROUP_SHANTY        33
 #define GROUP_SHANTY_COLOUR    (red(22))
-#define GROUP_SHANTY_COST   0        /* Unused */
-#define GROUP_SHANTY_COST_MUL   1    /* Unused */
+#define GROUP_SHANTY_COST   0   /* Unused */
+#define GROUP_SHANTY_COST_MUL   1       /* Unused */
 #define GROUP_SHANTY_BUL_COST  100000
-#define GROUP_SHANTY_TECH   0        /* Unused */
+#define GROUP_SHANTY_TECH   0   /* Unused */
 #define GROUP_SHANTY_FIREC     25
 
 #define SHANTY_MIN_PP     150
@@ -989,19 +807,19 @@ XXX: Then it shouldn't be here
 
 #define GROUP_FIRE        34
 #define GROUP_FIRE_COLOUR    (red(30))
-#define GROUP_FIRE_COST   0        /* Unused */
-#define GROUP_FIRE_COST_MUL   1    /* Unused */
+#define GROUP_FIRE_COST   0     /* Unused */
+#define GROUP_FIRE_COST_MUL   1 /* Unused */
 #define GROUP_FIRE_BUL_COST  1000
-#define GROUP_FIRE_TECH   0        /* Unused */
+#define GROUP_FIRE_TECH   0     /* Unused */
 #define GROUP_FIRE_FIREC  0
 
 #define GROUP_USED        35
-#define GROUP_USED_COLOUR (green(12))  /* Unused */
-#define GROUP_USED_COST   0            /* Unused */
-#define GROUP_USED_COST_MUL  1         /* Unused */
-#define GROUP_USED_BUL_COST  0         /* Unused */
-#define GROUP_USED_TECH   0            /* Unused */
-#define GROUP_USED_FIREC  0            /* Unused */
+#define GROUP_USED_COLOUR (green(12))   /* Unused */
+#define GROUP_USED_COST   0     /* Unused */
+#define GROUP_USED_COST_MUL  1  /* Unused */
+#define GROUP_USED_BUL_COST  0  /* Unused */
+#define GROUP_USED_TECH   0     /* Unused */
+#define GROUP_USED_FIREC  0     /* Unused */
 
 #define GROUP_RESIDENCE_ML 36
 #define GROUP_RESIDENCE_ML_COLOUR (cyan(24))
@@ -1024,7 +842,7 @@ XXX: Then it shouldn't be here
 #define GROUP_RESIDENCE_LH_COST 800
 #define GROUP_RESIDENCE_LH_COST_MUL 25
 #define GROUP_RESIDENCE_LH_BUL_COST 1000
-#define GROUP_RESIDENCE_LH_TECH 0          /* ?? */
+#define GROUP_RESIDENCE_LH_TECH 0       /* ?? */
 #define GROUP_RESIDENCE_LH_FIREC 75
 
 #define GROUP_RESIDENCE_MH 39
@@ -1043,11 +861,71 @@ XXX: Then it shouldn't be here
 #define GROUP_RESIDENCE_HH_TECH 0
 #define GROUP_RESIDENCE_HH_FIREC 75
 
-#define GROUP_IS_TRANSPORT(group) \
-            ((group == GROUP_TRACK) || \
-             (group == GROUP_ROAD) || \
-             (group == GROUP_RAIL) || \
-             (group == GROUP_POWER_LINE))
+#define GROUP_WATERWELL	   41
+#define GROUP_WATERWELL_COLOUR    (blue(31))
+#define GROUP_WATERWELL_COST      1
+#define GROUP_WATERWELL_COST_MUL 2
+#define GROUP_WATERWELL_BUL_COST      1
+#define GROUP_WATERWELL_TECH      0
+#define GROUP_WATERWELL_FIREC 0
+
+#define GROUP_DESERT 	  42
+#define GROUP_DESERT_COLOUR  (yellow(18))
+#define GROUP_DESERT_COST    0
+#define GROUP_DESERT_COST_MUL 1
+#define GROUP_DESERT_BUL_COST 1
+#define GROUP_DESERT_TECH    0
+#define GROUP_DESERT_FIREC   0
+
+#define GROUP_TREE 	   43
+#define GROUP_TREE_COLOUR  (green(12))
+#define GROUP_TREE_COST    0
+#define GROUP_TREE_COST_MUL 1
+#define GROUP_TREE_BUL_COST 1
+#define GROUP_TREE_TECH    0
+#define GROUP_TREE_FIREC   0
+
+#define GROUP_TREE2 	   44
+#define GROUP_TREE2_COLOUR  (green(12))
+#define GROUP_TREE2_COST    0
+#define GROUP_TREE2_COST_MUL 1
+#define GROUP_TREE2_BUL_COST 1
+#define GROUP_TREE2_TECH    0
+#define GROUP_TREE2_FIREC   0
+
+#define GROUP_TREE3 	   45
+#define GROUP_TREE3_COLOUR  (green(12))
+#define GROUP_TREE3_COST    0
+#define GROUP_TREE3_COST_MUL 1
+#define GROUP_TREE3_BUL_COST 1
+#define GROUP_TREE3_TECH    0
+#define GROUP_TREE3_FIREC   0
+
+#define BRIDGE_FACTOR 500 /* a bridge is that much more expensive than the land transport */
+
+#define GROUP_TRACK_BRIDGE        46
+#define GROUP_TRACK_BRIDGE_COLOUR 32   /* 32 is a brown */
+#define GROUP_TRACK_BRIDGE_COST   GROUP_TRACK_COST * BRIDGE_FACTOR
+#define GROUP_TRACK_BRIDGE_COST_MUL 2  
+#define GROUP_TRACK_BRIDGE_BUL_COST GROUP_TRACK_BUL_COST * BRIDGE_FACTOR
+#define GROUP_TRACK_BRIDGE_TECH   GROUP_TRACK_TECH
+#define GROUP_TRACK_BRIDGE_FIREC  0    /* unused */
+
+#define GROUP_ROAD_BRIDGE         47
+#define GROUP_ROAD_BRIDGE_COLOUR  (white(18))
+#define GROUP_ROAD_BRIDGE_COST    GROUP_ROAD_COST * BRIDGE_FACTOR
+#define GROUP_ROAD_BRIDGE_COST_MUL 2  
+#define GROUP_ROAD_BRIDGE_BUL_COST GROUP_ROAD_BUL_COST * BRIDGE_FACTOR
+#define GROUP_ROAD_BRIDGE_TECH    GROUP_ROAD_TECH
+#define GROUP_ROAD_BRIDGE_FIREC   0
+
+#define GROUP_RAIL_BRIDGE         48
+#define GROUP_RAIL_BRIDGE_COLOUR  (magenta(18))
+#define GROUP_RAIL_BRIDGE_COST    GROUP_RAIL_COST * BRIDGE_FACTOR
+#define GROUP_RAIL_BRIDGE_COST_MUL 2  
+#define GROUP_RAIL_BRIDGE_BUL_COST GROUP_RAIL_BUL_COST * BRIDGE_FACTOR
+#define GROUP_RAIL_BRIDGE_TECH    GROUP_RAIL_TECH
+#define GROUP_RAIL_BRIDGE_FIREC   0
 
 #define GROUP_IS_RESIDENCE(group) \
             ((group == GROUP_RESIDENCE_LL) || \
@@ -1057,18 +935,12 @@ XXX: Then it shouldn't be here
              (group == GROUP_RESIDENCE_MH) || \
              (group == GROUP_RESIDENCE_HH))
 
-#define GROUP_RESIDENCE_LL 4
-#define GROUP_RESIDENCE_LL_COLOUR (cyan(24))
-#define GROUP_RESIDENCE_LL_COST 1000
-#define GROUP_RESIDENCE_LL_COST_MUL 25
-#define GROUP_RESIDENCE_LL_BUL_COST 1000
-#define GROUP_RESIDENCE_LL_TECH 0
-#define GROUP_RESIDENCE_LL_FIREC 75
-
-
-#define MOUSE_TYPE_NORMAL 1
-#define MOUSE_TYPE_SQUARE 2
-#define MOUSE_BUTTON_REPEAT 4
+#define GROUP_IS_BARE(group) \
+	    ((group == GROUP_BARE) || \
+	     (group == GROUP_DESERT) || \
+	     (group == GROUP_TREE) || \
+	     (group == GROUP_TREE2) || \
+	     (group == GROUP_TREE3))
 
 #define red(x) (32 + x)
 #define green(x) (64 + x)
@@ -1078,437 +950,12 @@ XXX: Then it shouldn't be here
 #define cyan(x) (192 + x)
 #define white(x) (224 + x)
 
-
-struct map_point_info_struct
-{
-  int population;
-  int flags;
-  unsigned short coal_reserve;
-  unsigned short ore_reserve;
-  int int_1;
-  int int_2;
-  int int_3;
-  int int_4;
-  int int_5;
-  int int_6;
-  int int_7;
-};
-typedef struct map_point_info_struct Map_Point_Info;
-
-
-/* Set these flags to true when they need to be updated on the screen */
-struct update_scoreboard_struct
-{
-  int mps;
-  int mini;
-  int date;
-  int money;
-  int monthly;
-  int yearly_1;
-  int yearly_2;
-  long int message_area;
-};
-typedef struct update_scoreboard_struct Update_Scoreboard;
-
-
-/*
-  main functions
-  **************
-*/
-extern int lincity_main (int, char **);
-extern void client_main_loop (void);
-extern void do_error (const char *);
-extern void do_save_city (void);
-extern void remove_scene (char *);
-extern void save_city (char *);
-extern void do_load_city (void);
-extern void load_opening_city (char *);
-extern void load_city (char *);
-extern void reset_animation_times (void);
-extern void coal_reserve_setup (void);
-extern void ore_reserve_setup (void);
-extern void setup_river (void);
-extern void setup_river2 (int, int, int);
-extern void check_savedir (void);
-extern void make_savedir (void);
-extern void draw_save_dir (int);
-extern void input_save_filename (char *);
-extern void load_start_image (void);
-extern void start_image_text (void);
-extern void si_scroll_text (void);
-extern char si_next_char (FILE *);
-extern void get_real_time (void);
-extern void debug_writeval (int);
-extern int cheat (void);
-extern void print_cheat (void);
-extern void unprint_cheat (void);
-extern void order_select_buttons (void);
-extern void lincityrc (void);
-extern void check_for_old_save_dir (void);
-extern int count_groups (int);
-extern int compile_results (void);
-extern void print_results (void);
-extern void mail_results (void);
-extern void window_results (void);
-extern void init_path_strings (void);
-extern void lc_usleep (unsigned long);
-extern void dump_tcore (void);
-#ifndef LC_X11
-extern void parse_args (int, char **);
-#endif
-extern void sustainability_test (void);
-extern int sust_fire_cover (void);
-extern void check_endian (void);
-extern void eswap32 (int *);
-extern void eswap16 (unsigned short *);
-extern void malloc_failure (void);
-
-/*
-  fileutil
-  ********
-*/
-void malloc_failure (void);
-//FILE* fopen_read_gzipped (char* fn);
-//void fclose_read_gzipped (FILE* fp);
-void verify_package (void);
-
-/*
-  ldsvgui
-  *******
-*/
-void load_opening_city (char *s);
-void check_savedir (void);
-
-/*
-  opening
-  *******
-*/
-void load_start_image (void);
-
-
-/*
-  type init functions
-  *******************
-*/
-extern void init_types (void);
-extern void init_type_graphics (void);
-void init_costs (void);
-int get_selected_type_cost (short selected_type);
-extern char *load_graphic (char *);
-
-/*
-  screen functions
-  ****************
-*/
-#ifdef CS_PROFILE
-extern void FPgl_write (int, int, char *);
-extern void FPgl_getbox (int, int, int, int, void *);
-extern void FPgl_putbox (int, int, int, int, void *);
-extern void FPgl_fillbox (int, int, int, int, int);
-extern void FPgl_hline (int, int, int, int);
-extern void FPgl_line (int, int, int, int, int);
-extern void FPgl_setpixel (int, int, int);
-#endif
-extern void check_power_line_graphics (void);
-extern void check_water_graphics (void);
-extern void check_track_graphics (void);
-extern void check_rail_graphics (void);
-extern void check_road_graphics (void);
-extern int select_power_line_type (int, int, int, int);
-extern int select_water_type (int, int, int, int);
-extern int select_track_type (int, int, int, int);
-extern int select_rail_type (int, int, int, int);
-extern int select_road_type (int, int, int, int);
-extern void update_select_buttons (void);
-extern void draw_main_window_box (int);
-extern void draw_select_button_graphic (int, char *);
-extern void setcustompalette (void);
-extern void clip_main_window (void);
-extern void unclip_main_window (void);
-extern void initfont (void);
-extern void load_scroll_buttons (void);
-extern void draw_scroll_buttons (void);
-extern void update_mini_screen (void);
-extern void draw_mini_screen (void);
-extern void draw_big_mini_screen (void);
-extern void draw_mini_screen_pollution (void);
-extern void draw_mini_screen_fire_cover (void);
-extern void draw_mini_screen_cricket_cover (void);
-extern void draw_mini_screen_health_cover (void);
-extern void draw_mini_screen_ub40 (void);
-extern void draw_mini_screen_starve (void);
-extern void draw_mini_screen_coal (void);
-extern void draw_mini_screen_power (void);
-extern void draw_mini_screen_ocost (void);
-extern void draw_mini_screen_port (void);
-extern void draw_mini_screen_cursor (void);
-extern void print_stats (void);
-extern void print_total_money (void);
-int ask_launch_rocket_now (int x, int y);
-void print_date (void);
-extern void draw_market_cb (void);
-extern void clicked_market_cb (int, int);
-extern void close_market_cb (void);
-extern void draw_port_cb (void);
-extern void clicked_port_cb (int, int);
-extern void close_port_cb (void);
-extern int yn_dial_box (const char *, const char *, const char *, const char *);
-extern void ok_dial_box (const char *, int, const char *);
-extern int inv_sbut (int);
-extern void call_select_change_up (int);
-extern void beg_space_pad (const char *, int);
-extern void draw_up_pbar (int, int, int, int);
-extern void draw_down_pbar (int, int, int, int);
-extern void do_pbar_population (int);
-extern void do_pbar_tech (int);
-extern void do_pbar_food (int);
-extern void do_pbar_jobs (int);
-extern void do_pbar_coal (int);
-extern void do_pbar_goods (int);
-extern void do_pbar_ore (int);
-extern void do_pbar_steel (int);
-extern void do_pbar_money (int);
-extern void prog_box (const char *, int);
-/*
-  mouse functions -- are now in mouse.h, where they should be!
-  ***************
-*/
-
-/*
-  engine functions
-  ****************
-*/
-void initialize_tax_rates (void);
-void set_mappoint (int x, int y, short selected_type);
-void set_mappoint_used (int, int, int, int);
-int no_credit_build (int selected_type);
-void set_mappoint_ints (int fromx, int fromy, int x, int y);
-void new_city (int* originx, int* originy, int random_village);
-extern void engine_do_time_step (void);
-extern void do_residence (int, int);
-extern void debug_print (int);
-extern void do_power_source (int, int);
-extern void do_power_source_coal (int, int);
-extern void do_industry_l (int, int);
-extern void do_industry_h (int, int);
-extern void do_power_substation (int, int);
-extern int get_power (int, int, int, int);
-extern int add_a_substation (int, int);
-extern void remove_a_substation (int, int);
-extern void do_organic_farm (int, int);
-void init_mappoint_array (void);
-extern void shuffle_mappoint_array (void);
-extern void shuffle_substations (void);
-extern void do_coalmine (int, int);
-extern void do_oremine (int, int);
-extern void do_commune (int, int);
-extern void do_port (int, int);
-
-extern void do_pollution (void);
-extern void do_parkland (int, int);
-extern void do_university (int, int);
-extern void do_recycle (int, int);
-extern void do_health_centre (int, int);
-extern void do_rocket_pad (int, int);
-extern void launch_rocket (int x, int y);
-extern void do_windmill (int, int);
-extern void do_monument (int, int);
-extern void do_school (int, int);
-extern void do_blacksmith (int, int);
-extern void do_mill (int, int);
-extern void do_pottery (int, int);
-extern void do_firestation (int, int);
-extern void do_cricket (int, int);
-extern void clear_fire_health_and_cricket_cover (void);
-extern void do_fire_health_and_cricket_cover (void);
-extern void do_fire_cover (int, int);
-extern void do_health_cover (int, int);
-extern void do_cricket_cover (int, int);
-extern void do_random_fire (int, int, int);
-extern void do_fire (int, int);
-extern int spiral_find_group (int, int, int);
-extern int spiral_find_2x2 (int, int);
-extern void add_a_shanty (void);
-extern void remove_a_shanty (int, int);
-extern void update_shanty (void);
-extern void do_shanty (int, int);
-extern void do_tip (int, int);
-extern void update_tech_dep (int, int);
-/*
-   transport functions
-   *******************
-*/
-void connect_transport (int originx, int originy, int w, int h);
-extern void do_power_line (int, int);
-extern void do_track (int, int);
-extern void do_rail (int, int);
-extern void do_road (int, int);
-extern void general_transport (Map_Point_Info *, int *, int, int *);
-
-/*
-   market functions
-   ****************
-*/
-extern int get_food (int, int, int);
-extern int put_food (int, int, int);
-extern int get_jobs (int, int, int);
-extern int put_jobs (int, int, int);
-extern int get_goods (int, int, int);
-extern int put_goods (int, int, int);
-extern int get_ore (int, int, int);
-extern int put_ore (int, int, int);
-extern int get_coal (int, int, int);
-extern int put_coal (int, int, int);
-extern int add_a_market (int, int);
-extern void remove_a_market (int, int);
-extern void do_market (int, int);
-extern void shuffle_markets (void);
-extern int deal_with_transport (int, int, int, int);
-extern int get_steel (int, int, int);
-extern int put_steel (int, int, int);
-extern int get_waste (int, int, int);
-extern int put_waste (int, int, int);
-extern int get_stuff (int, int, int, int);
-extern int get_stuff2 (Map_Point_Info *, int, int);
-extern int get_stuff3 (Map_Point_Info *, int, int);
-extern int get_stuff4 (Map_Point_Info *, int, int);
-extern int put_stuff (int, int, int, int);
-extern int put_stuff2 (Map_Point_Info *, short *, int, int);
-extern int put_stuff3 (Map_Point_Info *, short *, int, int);
-extern int put_stuff4 (Map_Point_Info *, short *, int, int);
-
-#if defined SDL
-#warning "SDL defined"
-#include <SDL/SDL.h>
-
-extern void sdl_gl_write (int, int, char *);
-extern void sdl_gl_getbox (int, int, int, int, void *);
-extern void sdl_gl_putbox (int, int, int, int, void *);
-extern void sdl_gl_fillbox (int, int, int, int, Uint32 col);
-
-extern void sdl_gl_hline (int x1, int y1, int x2, Uint32 col);
-extern void sdl_gl_vline (int x1, int y1, int y2, Uint32 col);
-extern void sdl_gl_line (int x1, int y1, int x2, int y2, Uint32 col);
-
-extern void sdl_gl_setpixel (int x, int y, Uint32 col);
-extern void sdl_gl_setfontcolors (Uint32 bg, Uint32 fg);
-extern void sdl_gl_setfont (int, int, void *);
-extern void sdl_gl_enableclipping (void);
-extern void sdl_gl_setclippingwindow (int, int, int, int);
-extern void sdl_gl_disableclipping (void);
-
-extern void sdl_blit (int x, int y, int w, int h, SDL_Surface *);
-
-/* Wait for a key or some other event */
-extern int sdl_wait_for_key (void);
-extern int sdl_update_wait_for_key (void);
-
-extern int sdl_check_key (void);
-extern int sdl_update_check_key (void);
-
-#define sdl_map_rgb(r,g,b) SDL_MapRGB(display.surface->format, r, g, b)
-
-#define sdl_video() (display.surface)
-
-#define sdl_flip() SDL_Flip(display.surface)
-
-extern void sdl_clear (Uint32 col);
-
-#define Fgl_write(a,b,c) sdl_gl_write(a,b,c)
-#define Fgl_getbox(a,b,c,d,e) sdl_gl_getbox(a,b,c,d,e)
-#define Fgl_putbox(a,b,c,d,e) sdl_gl_putbox(a,b,c,d,e)
-#define Fgl_fillbox(a,b,c,d,e) sdl_gl_fillbox(a,b,c,d,e)
-#define Fgl_hline(a,b,c,d) sdl_gl_hline(a,b,c,d)
-#define Fgl_line(a,b,c,d,e) sdl_gl_line(a,b,c,d,e)
-#define Fgl_setpixel(a,b,c) sdl_gl_setpixel(a,b,c)
-#define Fgl_setfontcolors(a,b) sdl_gl_setfontcolors(a,b)
-#define Fgl_setfont(a,b,c) sdl_gl_setfont(a,b,c)
-#define Fgl_enableclipping() sdl_gl_enableclipping()
-#define Fgl_setclippingwindow(a,b,c,d) sdl_gl_setclippingwindow(a,b,c,d)
-#define Fgl_disableclipping() sdl_gl_disableclipping()
-
-
-
-#elif defined LC_X11
-/* ----- X11 functions ----- */
-extern void Fgl_write (int, int, const char *);
-extern void open_write (int, int, const char *);
-extern void Fgl_getbox (int, int, int, int, void *);
-extern void Fgl_putbox (int, int, int, int, void *);
-extern void Fgl_fillbox (int, int, int, int, int);
-extern void Fgl_hline (int, int, int, int);
-extern void Fgl_line (int, int, int, int, int);
-extern void Fgl_setpixel (int, int, int);
-extern void Fgl_setfontcolors (int, int);
-extern void Fgl_setfont (int, int, void*);
-extern void Fgl_enableclipping (void);
-extern void Fgl_setclippingwindow (int, int, int, int);
-extern void Fgl_disableclipping (void);
-#ifdef USE_X11_PIXMAPS
-#define USE_PIXMAPS
-extern void init_pixmaps (void);
-extern void init_icon_pixmap (short);
-extern void update_pixmap (int, int, int, int, int, int, int, char *);
-#endif
-
-#elif defined (WIN32)
-/* ----- Win32 functions ----- */
-extern void gl_setpalettecolor (long, long, long, long);
-extern void Fgl_write (int, int, const char *);
-extern void open_write (int, int, const char *);
-extern void Fgl_getbox (int, int, int, int, void *);
-extern void Fgl_putbox (int, int, int, int, void *);
-extern void Fgl_fillbox (int, int, int, int, int);
-extern void Fgl_hline (int, int, int, int);
-extern void Fgl_line (int, int, int, int, int);
-extern void Fgl_setpixel (int, int, int);
-extern void Fgl_setfontcolors (int, int);
-extern void Fgl_setfont (int, int, void*);
-extern void Fgl_enableclipping (void);
-extern void Fgl_setclippingwindow (int, int, int, int);
-extern void Fgl_disableclipping (void);
-#define USE_PIXMAPS		/* Always */
-extern void init_pixmaps (void);
-extern void init_icon_pixmap (short);
-extern void update_pixmap (int, int, int, int, int, int, int, char *);
-
-#else
-/* ----- SVGALIB functions ----- */
-/* profiling */
-#ifdef CS_PROFILE
-#define Fgl_write(a,b,c) FPgl_write(a,b,c)
-#define Fgl_getbox(a,b,c,d,e) FPgl_getbox(a,b,c,d,e)
-#define Fgl_putbox(a,b,c,d,e) FPgl_putbox(a,b,c,d,e)
-#define Fgl_fillbox(a,b,c,d,e) FPgl_fillbox(a,b,c,d,e)
-#define Fgl_hline(a,b,c,d) FPgl_hline(a,b,c,d)
-#define Fgl_line(a,b,c,d,e) FPgl_line(a,b,c,d,e)
-#define Fgl_setpixel(a,b,c) FPgl_setpixel(a,b,c)
-#define Fgl_setfontcolors(a,b) gl_setfontcolors(a,b)
-#define Fgl_setfont(a,b,c) gl_setfont(a,b,c)
-#define Fgl_enableclipping()   gl_enableclipping()
-#define Fgl_setclippingwindow(a,b,c,d)   gl_setclippingwindow(a,b,c,d)
-#define Fgl_disableclipping()   gl_disableclipping()
-#else
-#define Fgl_write(a,b,c) gl_write(a,b,c)
-#define Fgl_getbox(a,b,c,d,e) gl_getbox(a,b,c,d,e)
-#define Fgl_putbox(a,b,c,d,e) gl_putbox(a,b,c,d,e)
-#define Fgl_fillbox(a,b,c,d,e) gl_fillbox(a,b,c,d,e)
-#define Fgl_hline(a,b,c,d) gl_hline(a,b,c,d)
-#define Fgl_line(a,b,c,d,e) gl_line(a,b,c,d,e)
-#define Fgl_setpixel(a,b,c) gl_setpixel(a,b,c)
-#define Fgl_setfontcolors(a,b) gl_setfontcolors(a,b)
-#define Fgl_setfont(a,b,c) gl_setfont(a,b,c)
-#define Fgl_enableclipping()   gl_enableclipping()
-#define Fgl_setclippingwindow(a,b,c,d)   gl_setclippingwindow(a,b,c,d)
-#define Fgl_disableclipping()   gl_disableclipping()
-#endif
-
-#endif
 /*
   *******   end of lin-city.h   ***********
   *****************************************
 */
 
+/* FIXME : isn't it forbidden to include .h in .h ?  :-) */
 #include "lintypes.h"
 
 #endif /* __lin_city_h__ */
