@@ -1,7 +1,6 @@
 #ifndef ALL_MODULES_H
 #define ALL_MODULES_H
 
-#include "all_modules.h"
 #include "blacksmith.h"
 #include "coalmine.h"
 #include "coal_power.h"
@@ -36,5 +35,6 @@
 #include "water.h"
 #include "windmill.h"
 #include "market.h"
+#include "waterwell.h"
 
 #endif
