@@ -8,13 +8,16 @@
 #define __modules_h__
 
 #include "../lctypes.h"
-#include "../lcintl.h"
+#include "tinygettext/gettext.hpp"
 #include "../engglobs.h"
 #include "../engine.h"
 #include "../stats.h"
 #include "gui_interface/mps.h"
 #include "../lclib.h"
 
+#include "market.h"
+#include "../power.h"
+
 // for real_time
 //#include "cliglobs.h"
 
