@@ -6,8 +6,12 @@
 #ifndef __simulate_h__
 #define __simulate_h__
 
-void new_city (int* originx, int* originy, int random_village);
-void count_all_groups (int* group_count);
-void do_time_step (void);
+void do_time_step(void);
+int count_groups(int gr);
+void count_all_groups(int *group_count);
+void set_mappoint(int x, int y, short selected_type);
+void do_rand_ecology(int x, int y);
 
-#endif	/* __simulate_h__ */
+extern void connect_rivers(void);
+
+#endif /* __simulate_h__ */
